//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Core.DSCVersionService;

public partial class Admin : System.Web.UI.MasterPage {
    private const int maxDepth = 1;
    private string relativeUrl = null;

    protected string SiteName {
        get { return SiteConfigurationSection.GetSection().Name; }
    }

    public HtmlHead Head {
        get { return adminHead; }
    }

    protected override void OnInit(EventArgs e) {
        //Utils.EnsureSSLEnabled();
        base.OnInit(e);
    }
    protected void Page_Load(object sender, EventArgs e) {
        lnkIcon.Href = FileController.GetFileUrl("favicon.ico");
        Page.Title = SiteName + (null != SiteMap.CurrentNode ? " - " + SiteMap.CurrentNode.Title : "");
        lnkHelp.NavigateUrl = (null == SiteMap.CurrentNode) || (null == SiteMap.CurrentNode["helplink"]) ? SiteNavigation.DscOnlineHelp :
            SiteNavigation.DscDocumentRoot + SiteMap.CurrentNode["helplink"];
        if (!IsPostBack) {
            BindMenu();
        }

        if (!IsPostBack) {
            try {
                VersionInfo version = (VersionInfo)Application["DSCVersion"];
                if (null == version) {
                    version = WebUtils.CheckVersion();
                    Application["DSCVersion"] = version;
                }
                if (version.NewerVersionAvailable) {
                    litVersion.Text = string.Format("New version <a target='_blank' href='{0}'>{1}</a> available", 
                        version.GetLatestVersionUrl, version.LatestVersion);
                }
            } catch (Exception) {
                //ignore version check errors
            }
        }
    }

    protected void lnkLogout_Click(object sender, EventArgs e) {
        FormsAuthentication.SignOut();
        Response.Redirect(SiteNavigation.HomePage);
    }

    private void BindMenu() {
        relativeUrl = SiteNavigation.GetRelativePathToApplicatonRoot(Request.RawUrl);
        SiteMapDataSourceView view = (SiteMapDataSourceView)SiteMapDataSourceAdmin.GetView("");
        SiteMapNodeCollection collection = (SiteMapNodeCollection)view.Select(DataSourceSelectArguments.Empty);
        Recurse(tvwMenu.Nodes, collection, 1);
    }

    protected void tvwMenu_TreeNodeCollapsed(object sender, TreeNodeEventArgs e) {
        SetCollapsePreference(GetPerferenceKey(e.Node), true);
        udpTreeView.Update();
    }

    protected void tvwMenu_TreeNodeExpanded(object sender, TreeNodeEventArgs e) {
        SetCollapsePreference(GetPerferenceKey(e.Node), false);
        udpTreeView.Update();
    }

    private void Recurse(TreeNodeCollection nodes, SiteMapNodeCollection collection, int depth) {
        foreach (SiteMapNode item in collection) {
            if ((null != item["visible"]) && (!bool.Parse(item["visible"])))
                continue;

            TreeNode node = new TreeNode();
            node.Text = item.Title;
            if (string.IsNullOrEmpty(item.Url))
                node.SelectAction = TreeNodeSelectAction.None;
            else {
                node.NavigateUrl = GetUrl(item);
                if (relativeUrl.Equals(SiteNavigation.GetRelativePathToApplicatonRoot(ResolveUrl(item.Url)), StringComparison.OrdinalIgnoreCase))
                    node.Selected = true;
            }
            node.Expanded = !GetCollapsePreference(GetPerferenceKey(node));
            nodes.Add(node);

            if ((maxDepth >= depth) && item.HasChildNodes) {
                Recurse(node.ChildNodes, item.ChildNodes, depth + 1);
            }
        }
    }

    private string GetUrl(SiteMapNode item) {
        bool useSSL = SiteNavigation.UseSSL && 
            ((null == item["useSSL"]) || bool.Parse(item["useSSL"]));
        string url = item.Url;
        if (url.StartsWith(@"~"))
            url = SiteNavigation.ResolveUrlInText(url);
        return SiteNavigation.ResolveAbsoluteUrl(useSSL, url);
    }

    private bool GetCollapsePreference(string key) {
        return Profile.AdminTreeViewPreference.Contains(key.ToLower());
    }

    private void SetCollapsePreference(string key, bool collapsed) {
        key = key.ToLower();
        if (collapsed && (!Profile.AdminTreeViewPreference.Contains(key)))
            Profile.AdminTreeViewPreference.Add(key);
        else if ((!collapsed) && Profile.AdminTreeViewPreference.Contains(key))
            Profile.AdminTreeViewPreference.Remove(key);
    }

    private string GetPerferenceKey(TreeNode node) {
        return string.Format("{0}_{1}", node.Text, node.NavigateUrl);
    }
}
