//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Catalog_Attributes : DSCPage {
    private string name, description;
    private int selectionTypeId, displayControlTypeId;
    private bool required;

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            BindControls();
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        lblMessage.Text = dvwAttribute.CurrentMode == DetailsViewMode.Edit ? "Update Attribute" : "Add a New Attribute";
    }

    private void BindControls() {
        gvwAttributeList.DataSource = DSCAttribute.GetAll();
        gvwAttributeList.DataBind();
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        dvwAttribute.ChangeMode(DetailsViewMode.Insert);
        gvwAttributeList.Enabled = true;
    }

    protected void gvwAttributeList_RowEditing(object sender, GridViewEditEventArgs e) {
        gvwAttributeList.Enabled = false;
        dvwAttribute.ChangeMode(DetailsViewMode.Edit);
        dvwAttribute.DataSource = new DSCAttribute[] { DSCAttribute.Get((int)gvwAttributeList.DataKeys[e.NewEditIndex]["AttributeId"]) };
        dvwAttribute.DataBind();
    }

    protected void gvwAttributeList_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        dvwAttribute.ChangeMode(DetailsViewMode.Insert);
        DSCAttribute.Delete((int)gvwAttributeList.DataKeys[e.RowIndex]["AttributeId"]);
        BindControls();
    }

    protected void dvwAttribute_ItemUpdating(object sender, DetailsViewUpdateEventArgs e) {
        if (IsValid) {
            GetAttributeValuesFromControls();
            DSCAttribute.Update((int)dvwAttribute.DataKey["AttributeId"], name, description, required, selectionTypeId, displayControlTypeId);
            dvwAttribute.ChangeMode(DetailsViewMode.Insert);
            BindControls();
            gvwAttributeList.Enabled = true;
        }
    }

    protected void dvwAttribute_ItemInserting(object sender, DetailsViewInsertEventArgs e) {
        if (IsValid) {
            GetAttributeValuesFromControls();
            DSCAttribute.Add(name, description, required, selectionTypeId, displayControlTypeId);
            ClearControlValues();
            BindControls();
        }
    }

    private void GetAttributeValuesFromControls() {
        TextBox txtAttributeName = (TextBox)dvwAttribute.FindControl("txtAttributeName");
        name = txtAttributeName.Text;
        CheckBox chkRequired = (CheckBox)dvwAttribute.FindControl("chkRequired");
        required = chkRequired.Checked;
        DropDownList ddlSelectionType = (DropDownList)dvwAttribute.FindControl("ddlSelectionType");
        selectionTypeId = int.Parse(ddlSelectionType.SelectedValue);
        DropDownList ddlDisplayControl = (DropDownList)dvwAttribute.FindControl("ddlDisplayControl");
        displayControlTypeId = int.Parse(ddlDisplayControl.SelectedValue);
        TextBox txtDescription = (TextBox)dvwAttribute.FindControl("txtDescription");
        description = Utils.StringChangeEmptyToNull(txtDescription.Text);
    }

    private void ClearControlValues() {
        TextBox txtAttributeName = (TextBox)dvwAttribute.FindControl("txtAttributeName");
        txtAttributeName.Text = string.Empty;
        CheckBox chkRequired = (CheckBox)dvwAttribute.FindControl("chkRequired");
        chkRequired.Checked = false;
        DropDownList ddlSelectionType = (DropDownList)dvwAttribute.FindControl("ddlSelectionType");
        ddlSelectionType.SelectedIndex = 0;
        DropDownList ddlDisplayControl = (DropDownList)dvwAttribute.FindControl("ddlDisplayControl");
        ddlDisplayControl.SelectedIndex = 0;
        TextBox txtDescription = (TextBox)dvwAttribute.FindControl("txtDescription");
        txtDescription.Text = string.Empty;
    }
}
