//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Catalog_Categories : DSCPage {
    private int addedCategoryId;

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            InitializeCategoryTreeView();
            dvwCategory.ChangeMode(DetailsViewMode.Insert);
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        lblMessage.Text = dvwCategory.CurrentMode == DetailsViewMode.ReadOnly ? string.Empty : 
            (dvwCategory.CurrentMode == DetailsViewMode.Edit ? "Update Category" : "Add a New Category");
    }

    private void InitializeCategoryTreeView() {
        tvwCategory.Nodes.Clear();
        Category[] categories = Category.GetCategories();
        foreach (Category c in categories) {
            AddCategoryToTreeNode(tvwCategory.Nodes, c);
        }
        pnlEmptyManufacturer.Visible = categories.Length == 0;
        if (categories.Length == 0) {
            dvwCategory.ChangeMode(DetailsViewMode.Insert);
        }
    }

    private void AddCategoryToTreeNode(TreeNodeCollection nodes, Category c) {
        TreeNode node = new TreeNode(FormatCategoryTitle(c, CategoryStatistics.Get(c.CategoryId)), c.CategoryId.ToString());
        nodes.Add(node);
        if (null != c.SubCategories) {
            foreach (Category sub in c.SubCategories) {
                AddCategoryToTreeNode(node.ChildNodes, sub);
            }
        }
    }

    private string FormatCategoryTitle(Category c, CategoryStatistics s) {
        return string.Format("{0} ({1})", c.Name, s.ProductCount);
    }
    
    protected void odsCategoryDetail_Inserted(object sender, ObjectDataSourceStatusEventArgs e) {
        addedCategoryId = (int)e.ReturnValue;
    }

    protected void tvwCategory_SelectedNodeChanged(object sender, EventArgs e) {
        dvwCategory.ChangeMode(DetailsViewMode.ReadOnly);
    }

    private void tvwCategory_Refresh() {
        tvwCategory_Refresh(null);
    }

    private void tvwCategory_Refresh(string valuePath) {
        InitializeCategoryTreeView();
        tvwCategory.ExpandAll();
        if (!string.IsNullOrEmpty(valuePath)) {
            TreeNode node = tvwCategory.FindNode(valuePath);
            if (null != node) {
                node.Selected = true;
            }
        }
    }

    protected void dvwCategory_ItemInserted(object sender, DetailsViewInsertedEventArgs e) {
        tlbCategoryStatus.ShowText(string.Format("Added.", addedCategoryId));
        string parentCategoryId = e.Values[1] as string;
        string valuesPath = string.Empty;
        if (!string.IsNullOrEmpty(parentCategoryId)) {
            TreeNode node = FindNodeByValue(tvwCategory.Nodes, parentCategoryId);
            if (null != node) {
                valuesPath = node.ValuePath + tvwCategory.PathSeparator;
            }
        }
        tvwCategory_Refresh(valuesPath + addedCategoryId.ToString());
    }

    /// <summary>
    /// Loop through all the tree nodes and find out the node matching the value assuming all values in nodes are unique.
    /// </summary>
    /// <param name="value"></param>
    /// <returns></returns>
    private TreeNode FindNodeByValue(TreeNodeCollection nodes, string value) {
        foreach (TreeNode node in nodes) {
            if (node.Value == value) {
                return node;
            }
            if ((null != node.ChildNodes) && (node.ChildNodes.Count > 0)) {
                TreeNode foundNode = FindNodeByValue(node.ChildNodes, value);
                if (null != foundNode) {
                    return foundNode;
                }
            }
        }
        return null;
    }

    protected void dvwCategory_ItemDeleted(object sender, DetailsViewDeletedEventArgs e) {
        tlbCategoryStatus.ShowText(string.Format("Deleted.", e.Keys[0]));
        tvwCategory_Refresh();
    }

    protected void dvwCategory_ItemUpdated(object sender, DetailsViewUpdatedEventArgs e) {
        tlbCategoryStatus.ShowText(string.Format("Saved.", e.Keys[0]));
        tvwCategory_Refresh(tvwCategory.SelectedNode.ValuePath);
    }

    protected void dvwCategory_DataBound(object sender, EventArgs e) {
        if (null != dvwCategory.DataItem) {
            Category c = (Category)dvwCategory.DataItem;
            Button btnDelete = (Button)dvwCategory.FindControl("btnDelete");
            if (null != btnDelete) {
                btnDelete.Visible = c.CanDelete();
            }
        }
        // set default values when insert
        if (DetailsViewMode.Insert == dvwCategory.CurrentMode) {
            Controls_NumberTextBox ntbShowLevels = (Controls_NumberTextBox)dvwCategory.FindControl("ntbShowLevels");
            ntbShowLevels.Text = "2";
            Controls_NumberTextBox ntbSortOrder = (Controls_NumberTextBox)dvwCategory.FindControl("ntbSortOrder");
            ntbSortOrder.Text = "0";
            CheckBox chkUsefulLinks = (CheckBox)dvwCategory.FindControl("chkUsefulLinks");
            chkUsefulLinks.Checked = true;
            DropDownList ddlCategoryParent = (DropDownList)dvwCategory.FindControl("ddlCategoryParent");
            ListItem item = ddlCategoryParent.Items.FindByValue(tvwCategory.SelectedValue);
            if (null != item) {
                item.Selected = true;
            }
        } else if (DetailsViewMode.ReadOnly == dvwCategory.CurrentMode) {
            Button btnAddProduct = (Button)dvwCategory.FindControl("btnAddProduct");
            if (null != btnAddProduct) {
                btnAddProduct.Text = "Add Product to Category: " + ((Category)dvwCategory.DataItem).Name;
                if (0 == tvwCategory.SelectedNode.ChildNodes.Count) {
                    btnAddProduct.Enabled = true;
                    btnAddProduct.ToolTip = string.Format("Click to add product to the category '{0}'", tvwCategory.SelectedNode.Text);
                } else {
                    btnAddProduct.Enabled = false;
                    btnAddProduct.ToolTip = "You can only add products to the leaf level categories. Please select a leaf level category in the tree selection box.";
                }
            }
        }
    }

    protected void cvdNameExist_ServerValidate(object source, ServerValidateEventArgs args) {
        TextBox txtCategoryName = (TextBox)((Control)source).NamingContainer.FindControl("txtCategoryName");
        DropDownList ddlCategoryParent = (DropDownList)((Control)source).NamingContainer.FindControl("ddlCategoryParent");
        ListItem item = ddlCategoryParent.Items.FindByValue(tvwCategory.SelectedValue);
        int parentId = 0;
        int.TryParse(ddlCategoryParent.SelectedValue, out parentId);
        Category[] categories = Category.GetCategories(parentId, 2);
        if (0 != parentId) {
            categories = (null != categories) && (0 < categories.Length) && categories[0].HasChildren && (null != categories[0].SubCategories) ?
                categories[0].SubCategories : null;
        }
        if (null != categories) {
            foreach (Category c in categories) {
                if (c.Name.Equals(txtCategoryName.Text, StringComparison.OrdinalIgnoreCase)) {
                    args.IsValid = false;
                    return;
                }
            }
        }
        args.IsValid = true;
    }

    protected void cvdPriceRanges_ServerValidate(object source, ServerValidateEventArgs args) {
        TextBox txtPriceRanges = (TextBox)((Control)source).NamingContainer.FindControl("txtPriceRanges");
        if (!string.IsNullOrEmpty(txtPriceRanges.Text.Trim())) {
            decimal value;
            foreach (string price in txtPriceRanges.Text.Split(',', ' ', ';')) {
                string p = price.Trim();
                if ((!string.IsNullOrEmpty(p)) && (!decimal.TryParse(p, out value))) {
                    args.IsValid = false;
                    return;
                }
            }
        }
        args.IsValid = true;
    }
}
