//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Products_Manufacturer : DSCPage {
    private string name, url;
    private int? imageId;

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            BindControls();
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        lblMessage.Text = dvwManufacturer.CurrentMode == DetailsViewMode.Edit ? "Edit Manufacturer" : "Add a Manufacturer";
    }

    private void BindControls() {
        gvwManufacturers.DataSource = Manufacturer.GetAll();
        gvwManufacturers.DataBind();
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        dvwManufacturer.ChangeMode(DetailsViewMode.Insert);
        gvwManufacturers.Enabled = true;
    }

    protected void gvwManufacturers_RowEditing(object sender, GridViewEditEventArgs e) {
        gvwManufacturers.Enabled = false;
        dvwManufacturer.ChangeMode(DetailsViewMode.Edit);
        dvwManufacturer.DataSource = new Manufacturer[] { Manufacturer.Get((int)gvwManufacturers.DataKeys[e.NewEditIndex]["ManufacturerId"]) };
        dvwManufacturer.DataBind();
    }

    protected void gvwManufacturers_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        dvwManufacturer.ChangeMode(DetailsViewMode.Insert);
        Manufacturer.Delete((int)gvwManufacturers.DataKeys[e.RowIndex]["ManufacturerId"]);
        BindControls();
    }

    protected void dvwManufacturer_ItemUpdating(object sender, DetailsViewUpdateEventArgs e) {
        if (IsValid) {
            GetValuesFromControls();
            Manufacturer.Update((int)dvwManufacturer.DataKey["ManufacturerId"], name, imageId, url);
            dvwManufacturer.ChangeMode(DetailsViewMode.Insert);
            BindControls();
            gvwManufacturers.Enabled = true;
        }
    }

    protected void dvwManufacturer_ItemInserting(object sender, DetailsViewInsertEventArgs e) {
        if (IsValid) {
            GetValuesFromControls();
            Manufacturer.Add(name, imageId, url);
            ClearControlValues();
            BindControls();
        }
    }

    private void GetValuesFromControls() {
        TextBox txtName = (TextBox)dvwManufacturer.FindControl("txtName");
        name = txtName.Text;
        TextBox txtUrl = (TextBox)dvwManufacturer.FindControl("txtUrl");
        url = Utils.StringChangeEmptyToNull(txtUrl.Text);
        Controls_UploadImages iupCategoryImage = (Controls_UploadImages)dvwManufacturer.FindControl("iupCategoryImage");
        imageId = iupCategoryImage.ImageId;
    }

    private void ClearControlValues() {
        TextBox txtName = (TextBox)dvwManufacturer.FindControl("txtName");
        txtName.Text = string.Empty;
        TextBox txtUrl = (TextBox)dvwManufacturer.FindControl("txtUrl");
        txtUrl.Text = string.Empty;
        Controls_UploadImages iupCategoryImage = (Controls_UploadImages)dvwManufacturer.FindControl("iupCategoryImage");
        iupCategoryImage.ImageId = null;
    }

}
