//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;
using AjaxControlToolkit;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Catalog_ProductEdit : DSCPage {
    private int productId;
    private int defaultCategoryId;
    private int? activeTabIndex = null;

    protected void Page_Load(object sender, EventArgs e) {
        lblError.Visible = false;
        productId = Utils.GetIntParameter("pid", 0);
        if (!IsPostBack) {
            if (productId > 0) {
                // view or edit scenario
                if (odsProduct.SelectParameters.Count == 0) {
                    odsProduct.SelectParameters.Add("productId", productId.ToString());
                }
                if (Utils.CheckParameterExist("readonly"))
                    fvwProduct.ChangeMode(FormViewMode.ReadOnly);
            } else { // add scenario
                fvwProduct.ChangeMode(FormViewMode.Insert);
                TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
                defaultCategoryId = Utils.GetIntParameter("cid", 0);
                if (0 == defaultCategoryId) {
                    tbcProduct.ActiveTabIndex = 0; //need to start from categories tab
                    //Todo: use the first category as default category
                    //defaultCategoryId = Category.GetAllLeafCategories()[0].CategoryId;
                }
            }
            string statusMsg = Utils.GetParameter("status", null);
            if (!string.IsNullOrEmpty(statusMsg)) {
                Controls_TransitionalLabel tlbStatus = (Controls_TransitionalLabel)fvwProduct.FindControl("tlbStatus");
                tlbStatus.ShowText(statusMsg);
            }
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        lblMessage.Text = fvwProduct.CurrentMode == FormViewMode.ReadOnly ? string.Empty :
            (fvwProduct.CurrentMode == FormViewMode.Edit ? "Update Product" : "Add a New Product");
    }

    protected void fvwProduct_ModeChanging(object sender, FormViewModeEventArgs e) {
        TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
        activeTabIndex = tbcProduct.ActiveTabIndex;
    }

    protected void fvwProduct_ItemInserted(object sender, FormViewInsertedEventArgs e) {
        if (null != e.Exception) {
            e.ExceptionHandled = HandleException(e.Exception);
            e.KeepInInsertMode = true;
        }
    }

    protected void fvwProduct_ItemInserting(object sender, FormViewInsertEventArgs e) {
        FillFormArguments(e.Values);
    }

    protected void fvwProduct_ItemUpdated(object sender, FormViewUpdatedEventArgs e) {
        Controls_TransitionalLabel tlbStatus = (Controls_TransitionalLabel)fvwProduct.FindControl("tlbStatus");
        tlbStatus.ShowText("Updated.");
    }

    protected void odsProduct_Inserted(object sender, ObjectDataSourceStatusEventArgs e) {
        if (null == e.Exception) {
            int productId = (int)e.ReturnValue;
            string message = "Added.";
            Product product = Product.Load(productId);
            Category[] categories = product.GetCategories();
            int defaultCategory = 1 == categories.Length ? categories[0].CategoryId : 0;
            Response.Redirect(string.Format("{0}?cid={1}&status={2}", SiteNavigation.ProductEditPage, defaultCategory, Server.UrlEncode(message)));
        }
    }

    private bool HandleException(Exception e) {
        if (null == e.InnerException)
            throw e; // need to expect innerException
        if (e.InnerException.Message.Contains("unique index 'IX_DSC_Product_SKU'")) { // duplicate SKU id
            lblError.Visible = true;
            lblError.Text = string.Format("There is already a product with SKU {0}. Please choose a different SKU.", productBasic.SKU);
            return true;
        }
        throw e;
    }

    protected void fvwProduct_ItemUpdating(object sender, FormViewUpdateEventArgs e) {
        if (IsValid)
            FillFormArguments(e.NewValues);
        else
            e.Cancel = true;
    }

    protected void cvdProductCategoryMap_ServerValidate(object source, ServerValidateEventArgs args) {
        TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
        args.IsValid = ((Admin_Controls_ProductCategoryMap)tbcProduct.Tabs[0].FindControl("ProductCategoryMap")).Categories.Count > 0;
    }


    /// <summary>
    /// This method is to work around the issue that naming container inside FormView breaks two-way binding
    /// </summary>
    private void FillFormArguments(IOrderedDictionary values) {
        TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
        Admin_Controls_ProductBasic productBasic = (Admin_Controls_ProductBasic)tbcProduct.Tabs[1].FindControl("productBasic");
        Admin_Controls_ProductMiscellaneous productMiscellaneous = (Admin_Controls_ProductMiscellaneous)tbcProduct.Tabs[5].FindControl("productMiscellaneous");
        if (!values.Contains("productName"))
            values.Add("productName", productBasic.ProductName);
        if (!values.Contains("sku"))
            values.Add("sku", productBasic.SKU);
        if (!values.Contains("shortDescription"))
            values.Add("shortDescription", productBasic.ShortDescription);
        if (!values.Contains("quantity"))
            values.Add("quantity", productBasic.Quantity);
        if (!values.Contains("price"))
            values.Add("price", productBasic.Price);
        if (!values.Contains("retailPrice"))
            values.Add("retailPrice", productMiscellaneous.RetailPrice);
        if (!values.Contains("salePrice"))
            values.Add("salePrice", productMiscellaneous.SalePrice);
        if (!values.Contains("cost"))
            values.Add("cost", productMiscellaneous.Cost);
        if (!values.Contains("manufacturerId"))
            values.Add("manufacturerId", productBasic.ManufacturerId);
        if (!values.Contains("manufacturerSKU"))
            values.Add("manufacturerSKU", productMiscellaneous.ManufacturerSKU);
        if (!values.Contains("statusId"))
            values.Add("statusId", 1);
        if (!values.Contains("productTypeId"))
            values.Add("productTypeId", productMiscellaneous.ProductTypeId);
        if (!values.Contains("shipTypeId"))
            values.Add("shipTypeId", productBasic.ShippingType);
        if (!values.Contains("shipEstimateId"))
            values.Add("shipEstimateId", productBasic.ShipEstimateId);
        if (!values.Contains("taxTypeId"))
            values.Add("taxTypeId", productBasic.TaxType);
        if (!values.Contains("weight"))
            values.Add("weight", productBasic.Weight);
        if (!values.Contains("weightMeasureId"))
            values.Add("weightMeasureId", productBasic.WeightMeasureId);
        if (!values.Contains("length"))
            values.Add("length", productBasic.Length);
        if (!values.Contains("height"))
            values.Add("height", productBasic.Height);
        if (!values.Contains("width"))
            values.Add("width", productBasic.Width);
        if (!values.Contains("dimensionMeasureId"))
            values.Add("dimensionMeasureId", productBasic.DimensionMeasureId);
        if (!values.Contains("sortOrder"))
            values.Add("sortOrder", productMiscellaneous.SortOrder);
        if (!values.Contains("timeCreated"))
            values.Add("timeCreated", productMiscellaneous.TimeCreated);
        if (!values.Contains("showIfOutofStock"))
            values.Add("showIfOutofStock", productMiscellaneous.ShowIfOutofStock);
        if (!values.Contains("featureCategories"))
            values.Add("categories", ((Admin_Controls_ProductCategoryMap)tbcProduct.Tabs[0].FindControl("ProductCategoryMap")).Categories);
        if (!values.Contains("images"))
            values.Add("images", ((Controls_UploadImages)tbcProduct.Tabs[2].FindControl("iupProductImage")).Images);
        if (!values.Contains("descriptors"))
            values.Add("descriptors", ((Admin_Controls_ProductDescriptorEdit)tbcProduct.Tabs[4].FindControl("pdeDescriptorEdit")).Descriptors);
        if (!values.Contains("attributes"))
            values.Add("attributes", ((Admin_Controls_ProductAttribute)tbcProduct.Tabs[3].FindControl("ProductAttribute")).ProductAttributes);
    }

    protected void fvwProduct_PreRender(object sender, EventArgs e) {
        if (null != activeTabIndex) {
            TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
            tbcProduct.ActiveTabIndex = (int)activeTabIndex;
        }
        if (FormViewMode.Insert == fvwProduct.CurrentMode) {
            Button btnUpdate = (Button)fvwProduct.FindControl("btnUpdate");
            btnUpdate.Text = "Add";
            btnUpdate.CommandName = "Insert";
            Button btnCancel = (Button)fvwProduct.FindControl("btnCancel");
            btnCancel.Visible = false;
            TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
            Admin_Controls_ProductCategoryMap ProductCategoryMap = (Admin_Controls_ProductCategoryMap)tbcProduct.Tabs[0].FindControl("ProductCategoryMap");
            if (null != ProductCategoryMap)
                ProductCategoryMap.DefaultCategoryId = defaultCategoryId;

            Admin_Controls_ProductBasic productBasic = (Admin_Controls_ProductBasic)tbcProduct.Tabs[1].FindControl("productBasic");
            productBasic.Mode = DetailsViewMode.Insert;

            Admin_Controls_ProductMiscellaneous productMiscellaneous = (Admin_Controls_ProductMiscellaneous)tbcProduct.Tabs[5].FindControl("productMiscellaneous");
            productMiscellaneous.Mode = DetailsViewMode.Insert;
        }
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        fvwProduct.ChangeMode(FormViewMode.ReadOnly);
        TabContainer tbcProduct = (TabContainer)fvwProduct.FindControl("tbcProduct");
        activeTabIndex = tbcProduct.ActiveTabIndex;
    }

    private void SendNotificationEmail(Product product, string email) {
        NameValueCollection tokens = Utils.GetSiteTokens();
        product.AddTokens(tokens);
        EmailManager.Send("ProductUpdate", tokens, SiteConfigurationSection.GetSection().SiteEmailAddress, new string[] { email });
    }
}
