//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public class OrderStatusUpdatingEventArgs : EventArgs {
    public int NewOrderStatusId;
    public string NewOrderStatus;

    public OrderStatusUpdatingEventArgs(int newOrderStatusId, string newOrderStatus) {
        NewOrderStatusId = newOrderStatusId;
        NewOrderStatus = newOrderStatus;
    }
}
public delegate void OrderStatusUpdatingEventHandler(object sender, OrderStatusUpdatingEventArgs e);

public partial class Admin_Controls_OrderStatusEdit : System.Web.UI.UserControl {
    private OrderStatus orderStatus = null;

    private OrderStatus savedOrderStatus {
        get { return (OrderStatus)ViewState["savedOrderStatus"]; }
        set { ViewState["savedOrderStatus"] = value; }
    }

    public OrderStatus OrderStatus {
        get { return orderStatus; }
        set { orderStatus = value; }
    }

    public string OrderPipeline {
        get { return (string)ViewState["OrderPipeline"]; }
        set { ViewState["OrderPipeline"] = value; }
    }

    public event OrderStatusUpdatingEventHandler Updating = null;

    protected void Page_PreRender(object sender, EventArgs e) {
        if (orderStatus != null) {
            BindOrderStatus();
            savedOrderStatus = orderStatus;
        }
    }

    private void BindOrderStatus() {
        fvwOrderStatus.DataSource = new OrderStatus[] { orderStatus };
        fvwOrderStatus.DataBind();
    }

    protected void fvwOrderStatus_ModeChanging(object sender, FormViewModeEventArgs e) {
        fvwOrderStatus.ChangeMode(e.NewMode);
        if ((e.NewMode != FormViewMode.Insert) && (null == orderStatus))
            orderStatus = savedOrderStatus;
    }

    protected void fvwOrderStatus_DataBound(object sender, EventArgs e) {
        if (FormViewMode.Edit == fvwOrderStatus.CurrentMode) {
            DropDownList ddlStatus = (DropDownList)fvwOrderStatus.FindControl("ddlStatus");
            ddlStatus.DataSource = OrderStatus.GetAvailableOrderStatus(OrderPipeline);
            ddlStatus.DataBind();
            WebUtils.SetDropDownListSelected(ddlStatus, savedOrderStatus.StatusId.ToString());
        }
    }

    protected void fvwOrderStatus_ItemUpdating(object sender, FormViewUpdateEventArgs e) {
        DropDownList ddlStatus = (DropDownList)fvwOrderStatus.FindControl("ddlStatus");
        OnUpdating(new OrderStatusUpdatingEventArgs(int.Parse(ddlStatus.SelectedValue), ddlStatus.SelectedItem.Text));
        fvwOrderStatus.ChangeMode(FormViewMode.ReadOnly);
    }

    protected virtual void OnUpdating(OrderStatusUpdatingEventArgs e) {
        if (null != Updating) {
            Updating(this, e);
        }
    }

}
