//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Controls_ShipTrackingEdit : System.Web.UI.UserControl {
    private List<OrderItem> orderItems;
    private int carrierId = 0;

    public List<OrderItem> OrderItems {
        get { return orderItems; }
        set { orderItems = value; }
    }

    public string TrackingNumber {
        get { return txtTrackingNumber.Text.Trim(); }
        set { txtTrackingNumber.Text = value; }
    }

    public int CarrierId {
        get { return int.Parse(ddlShipCarrier.SelectedValue); }
        set { carrierId = value; }
    }

    public DateTime ShipDate {
        get { return DateTime.Parse(txtShipDate.Text); }
        set { txtShipDate.Text = value.ToShortDateString(); }
    }

    public List<int> SelectedOrderItemIds {
        get {
            List<int> selectedIds = new List<int>();
            foreach (RepeaterItem item in rptOrderItems.Items) {
                CheckBox chkSelect = (CheckBox)item.FindControl("chkSelect");
                HiddenField hidOrderItemId = (HiddenField)item.FindControl("hidOrderItemId");
                if (chkSelect.Checked)
                    selectedIds.Add(int.Parse(hidOrderItemId.Value));
            }
            return selectedIds;
        }
    }

    public string ValidationGroup {
        set {
            foreach (Control control in Controls) {
                if (control is BaseValidator) {
                    ((BaseValidator)control).ValidationGroup = value;
                } else if (control is ValidationSummary) {
                    ((ValidationSummary)control).ValidationGroup = value;
                }
            }
        }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (null != orderItems) {
            rptOrderItems.DataSource = orderItems;
            rptOrderItems.DataBind();
        }
        if (string.IsNullOrEmpty(txtShipDate.Text))
            txtShipDate.Text = DateTime.Now.ToShortDateString();
    }

    protected void ddlShipCarrier_DataBound(object sender, EventArgs e) {
        if (0 != carrierId)
            WebUtils.SetDropDownListSelected(ddlShipCarrier, carrierId.ToString());
    }

    protected void rptOrderItems_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        if (!string.IsNullOrEmpty(txtTrackingNumber.Text)) {
            OrderItem orderItem = (OrderItem)e.Item.DataItem;
            if ((null != orderItem.ShipTracking) &&
                (0 == string.Compare(orderItem.ShipTracking.TrackingNumber, txtTrackingNumber.Text, true))) {
                CheckBox chkSelect = (CheckBox)e.Item.FindControl("chkSelect");
                chkSelect.Checked = true;
            }
        }
    }
}
