//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Payment;

public partial class Admin_Sale_OrderEdit : DSCPage {
    private int orderId;
    private Order order;

    private Order Order {
        get {
            if (null == order)
                order = Order.Get(orderId);
            return order;
        }
    }
    private void ReloadOrder() {
        order = Order.Get(orderId);
    }

    protected void Page_Load(object sender, EventArgs e) {
        orderId = Utils.GetIntParameter("oid");

        if (!IsPostBack) {
            lblOrderNumber.Text = Order.OrderNumber;
            lblOrderDate.Text = Order.Created.ToShortDateString();
            lnkUser.Text = string.Format("{0} {1}", Order.BillingAddress.FirstName, Order.BillingAddress.LastName);
            lnkUser.NavigateUrl = string.Format("{0}?uid={1}", SiteNavigation.UserEditPage, order.UserId);
            lblEmail.Text = Order.Email;
            lblShippingMethod.Text = Order.ShippingMethod;

            if (ShipType.IsDownloadMethod(SiteNavigation.GetHost(), order.ShippingMethod))
                steShipTracingEdit.Visible = false;
            else
                steShipTracingEdit.Order = Order;

            paymentSummary.CheckoutPaymentType = Order.CheckoutPaymentType.TypeEnum;
            paymentSummary.CreditCard = Order.CreditCard;
            paymentSummary.CustomField = Order.CustomField;
            oseStatus.OrderStatus = Order.OrderStatus;
            oseStatus.OrderPipeline = Order.OrderPipeline;
            auShippingAddress.Address = Order.ShippingAddress;
            auBillingAddress.Address = Order.BillingAddress;
            orderItems.Items = Order.OrderItems;
            orderItems.OrderId = orderId;
            lblTotalItem.Text = Order.OrderItemCount.ToString();
            orderTotal.OrderTotals = Order.OrderTotals;

            if (CheckoutPaymentTypeEnum.PaypalStandard == Order.CheckoutPaymentType.TypeEnum) {
                gvwPaymentTransaction.Columns[5].HeaderText = "Payer Status";
                gvwPaymentTransaction.Columns[6].HeaderText = "Payment Status";
            }
            gvwPaymentTransaction.DataSource = Order.PaymentTransactions;
            gvwPaymentTransaction.DataBind();
            gvwNote.DataSource = Order.OrderNotes;
            gvwNote.DataBind();
            rptAction.DataSource = Order.GetOrderPipelineActions();
            rptAction.DataBind();

            btnInvoice.OnClientClick = string.Format("window.open('{0}?oid={1}', '_blank'); return false;", SiteNavigation.InvoicePage, orderId);
            btnPackingSlip.OnClientClick = string.Format("window.open('{0}?oid={1}', '_blank'); return false;", SiteNavigation.PackingSlipPage, orderId);
            btnCancelOrder.Visible = Order.OrderStatus.StatusId != Constant.DB.OrderStatusCanceledId;
        }
    }

    protected void auShippingAddress_Updating(object sender, AddressUpdatingEventArgs e) {
        Order.UpdateAddress(orderId, false, e.AddressUpdating);
        ReloadOrder();
        auShippingAddress.Address = Order.ShippingAddress;
    }

    protected void auBillingAddress_Updating(object sender, AddressUpdatingEventArgs e) {
        Order.UpdateAddress(orderId, true, e.AddressUpdating);
        ReloadOrder();
        auBillingAddress.Address = Order.BillingAddress;
    }

    protected void oseStatus_Updating(object sender, OrderStatusUpdatingEventArgs e) {
        Order.SetStatus(orderId, e.NewOrderStatusId, string.Format("[{0}]: ", Utils.GetUserName()));
        DataBindStatusRelatedParts();
    }

    private void DataBindStatusRelatedParts() {
        ReloadOrder();
        oseStatus.OrderStatus = Order.OrderStatus;
        gvwNote.DataSource = Order.OrderNotes;
        gvwNote.DataBind();
        rptAction.DataSource = Order.GetOrderPipelineActions();
        rptAction.DataBind();
    }

    protected void btnAddNote_Click(object sender, EventArgs e) {
        if (IsValid) {
            Order.AddNote(orderId, string.Format("[{0}]: {1}", Utils.GetUserName(), txtNewNote.Text));
            txtNewNote.Text = string.Empty;

            ReloadOrder();
            gvwNote.DataSource = Order.OrderNotes;
            gvwNote.DataBind();
        }
    }

    protected void btnAction_Command(object sender, CommandEventArgs e) {
        Order.SetToNextStatusInPipeline(string.Format("[{0}]: ", Utils.GetUserName()));
        DataBindStatusRelatedParts();
    }

    protected void btnCancelOrder_Click(object sender, EventArgs e) {
        Order.Restock(orderId);
        Order.SetStatus(orderId, Constant.DB.OrderStatusCanceledId, string.Format("[{0}]: ", Utils.GetUserName()));
        DataBindStatusRelatedParts();
        btnCancelOrder.Visible = false;
    }

    /*
    protected void btnRefund_Click(object sender, EventArgs e) {
        CreditCardPaymentProvider provider = CreditCardPaymentService.GetProvider();
        PaymentTransaction pt = provider.Refund(Order, 10.00M);
        pt.Add(SiteNavigation.GetHost(), Order.OrderNumber);
        Order.AddNote(Order.OrderId, string.Format("[{0}]: Refunded {1:C}", Utils.GetUserName(), pt.Amount));

        DataBindStatusRelatedParts();
        gvwPaymentTransaction.DataSource = Order.PaymentTransactions;
        gvwPaymentTransaction.DataBind();
    }*/
}
