//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

public partial class Controls_ColorPicker : System.Web.UI.UserControl {
    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            rptRow.DataSource = ColorValues.GetColors();
            rptRow.DataBind();
        }
    }

    class ColorValues {
        private List<ColorValue> values;

        public List<ColorValue> Values {
            get { return values; }
        }

        public ColorValues(List<ColorValue> values) {
            this.values = values;
        }

        public static List<ColorValues> GetColors() {
            List<ColorValues> colors = new List<ColorValues>();
            int rowIndex = 0;
            for (int i = 0; i <= 15; i = i + 3) {
                colors.Add(new ColorValues(ColorValue.GetRow(rowIndex, i)));
                rowIndex++;
            }
            for (int i = 15; i >= 0; i = i - 3) {
                colors.Add(new ColorValues(ColorValue.GetRow(rowIndex, i)));
                rowIndex++;
            }
            // last row

            List<ColorValue> values = new List<ColorValue>();
            for (int i = 0; i < 18; i++) {
                values.Add(new ColorValue(
                    string.Format("{0:X}{0:X}{0:X}{0:X}{0:X}{0:X}", i % 16)));
            }
            colors.Add(new ColorValues(values));

            return colors;
        }
    }

    class ColorValue {
        private string value;
        public string Value {
            get { return value; }
        }

        public ColorValue(string value) {
            this.value = value;
        }

        public static List<ColorValue> GetRow(int rowIndex, int last) {
            List<ColorValue> values = new List<ColorValue>();
            for (int colIndex = 0; colIndex < 18; colIndex++) {
                values.Add(new ColorValue(
                    string.Format("{0:X}{0:X}{1:X}{1:X}{2:X}{2:X}", 
                        GetFirst(colIndex, rowIndex),
                        GetSecond(colIndex),
                        last)));
            }
            return values;
        }

        private static int GetFirst(int colIndex, int rowIndex) {
            if (rowIndex < 6) {
                switch (colIndex / 6) {
                    case 0:
                        return 3;
                    case 1:
                        return 6;
                    case 2:
                        return 15;
                }
            } else {
                switch (colIndex / 6) {
                    case 0:
                        return 0;
                    case 1:
                        return 9;
                    case 2:
                        return 12;
                }
            }
            throw new ApplicationException("Bad Color calculation");
        }

        private static int GetSecond(int colIndex) {
            int col = colIndex % 12;
            if (col >= 6)
                col = 11 - col;
            return col * 3;
        }
    }
}
