//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Xml;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Store_Controls_Colors : ValidatableUserControl {
    private string validationGroup;
    public override string ValidationGroup {
        set { validationGroup = value; }
    }

    private string errorMessagePrefix;
    public override string ErrorMessagePrefix {
        set { errorMessagePrefix = value; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            UIConfigurationSection section = UIConfigurationSection.GetSection();
            rptColors.DataSource = section.Colors;
            rptColors.DataBind();
        }
        foreach (RepeaterItem item in rptColors.Items) {
            TextBox txtColor = (TextBox)item.FindControl("txtColor");
            ScriptManager.RegisterStartupScript(this, typeof(Admin_Store_Controls_Colors), txtColor.ClientID,
                string.Format("InitColorPreview('{0}');", txtColor.ClientID), true);
        }
    }

    protected void rptColors_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        RequiredFieldValidator rvfColor = (RequiredFieldValidator)e.Item.FindControl("rvfColor");
        if (!string.IsNullOrEmpty(validationGroup))
            rvfColor.ValidationGroup = validationGroup;
        rvfColor.ErrorMessage = errorMessagePrefix + ((ColorConfigurationElement)e.Item.DataItem).Name + " is a required field.";

        TextBox txtColor = (TextBox)e.Item.FindControl("txtColor");
        txtColor.Attributes.Add("onchange", string.Format("InitColorPreview('{0}')", txtColor.ClientID));
        txtColor.Attributes.Add("onfocus", "ShowColorPicker(this)");
        txtColor.Attributes.Add("onblur", "HideColorPicker(this)");
        txtColor.Attributes.Add("colorName", string.Format("{0}", ((ColorConfigurationElement)e.Item.DataItem).Name));
        txtColor.Attributes.Add("spanColorPreview", string.Format("spColor_{0}", ((ColorConfigurationElement)e.Item.DataItem).Name));
    }

    public void SaveTo(UIConfigurationSection section) {
        foreach (RepeaterItem item in rptColors.Items) {
            Label lblColorName = (Label)item.FindControl("lblColorName");
            TextBox txtColor = (TextBox)item.FindControl("txtColor");
            section.Colors.Get(lblColorName.Text).Value = txtColor.Text;
        }
    }
}
