//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;
using DSC=DotShoppingCart.OpenSource.Core;

public partial class Admin_Controls_SiteAddress : ValidatableUserControl {
    public bool enableStoreUrl {
        set { pnlStoreUrl.Visible = value; }
    }

    public override string ValidationGroup {
        set {
            base.ValidationGroup = value;
            rfvStoreUrl.ValidationGroup = telPhone.ValidationGroup = etbSiteEmail.ValidationGroup = value;
        }
    }

    public override string ErrorMessagePrefix {
        set {
            base.ErrorMessagePrefix = value;
            telPhone.ErrorMessagePrefix = value + "Phone ";
            etbSiteEmail.ErrorMessagePrefix = value + "Site ";
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            SiteConfigurationSection section = SiteConfigurationSection.GetSection();
            txtStoreName.Text = section.Name;
            txtStoreUrl.Text = section.URL;
            txtAddress.Text = section.LocationAddress;
            txtCity.Text = section.LocationCity;
            txtState.Text = section.LocationState;
            Country c = Country.GetFromCodeISO3166(section.LocationCountry);
            if (null != c)
                ddlCountry.SelectedValue = c.CountryId.ToString();
            txtZipCode.Text = section.LocationZipcode;
            telPhone.Telephone = section.Phone;
            telPhone.Extension = section.PhoneExt;
            telFax.Telephone = section.Fax;
            telFax.Extension = section.FaxExt;
            etbSiteEmail.Text = section.SiteEmailAddress;
        }
    }

    public void SaveTo(SiteConfigurationSection section) {
        section.Name = txtStoreName.Text;
        if (pnlStoreUrl.Visible)
            section.URL = txtStoreUrl.Text;
        section.LocationAddress = txtAddress.Text;
        section.LocationCity = txtCity.Text;
        section.LocationState = DSC.Address.GetStandardStateName(txtState.Text.Trim(), int.Parse(ddlCountry.SelectedValue));
        section.LocationCountry = Country.Get(int.Parse(ddlCountry.SelectedValue)).CodeISO3166;
        section.LocationZipcode = txtZipCode.Text;
        section.Phone = telPhone.Telephone;
        section.PhoneExt = telPhone.Extension;
        section.Fax = telFax.Telephone;
        section.FaxExt = telFax.Extension;
        section.SiteEmailAddress = etbSiteEmail.Text;
    }

    protected void cvdState_ServerValidate(object source, ServerValidateEventArgs args) {
        try {
            DSC.Address.GetStandardStateName(txtState.Text.Trim(), int.Parse(ddlCountry.SelectedValue));
            args.IsValid = true;
        } catch (ApplicationException) {
            args.IsValid = false;
        }
    }
}
