//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Xml;
using System.Xml.Linq;
using System.Linq;
using System.Text.RegularExpressions;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_Store_Controls_Theme : System.Web.UI.UserControl {
    public event EventHandler DataLostConfirmed;

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            string script = "function SetImage(listBox) { " +
                "$get('" + imgTheme.ClientID + "').src = listBox.options[listBox.selectedIndex].value; " +
                "$get('" + imgTheme.ClientID + "').alt = listBox.options[listBox.selectedIndex].text; " +
                "}";
            ScriptManager.RegisterClientScriptBlock(this, typeof(Page), "SetImage", script, true);
        }
    }

    public void SaveTo(UIConfigurationSection section) {
        string theme = lstThemes.SelectedItem.Text;
        if (!section.ParentThemes.Equals(theme)) {
            //Update block data
            using (DSCDataContext dc = DBController.GetDataContext()) {
                foreach (var b in GetBlocks(theme)) {
                    Block block = dc.Blocks.Single(p => p.Name == b.Name);
                    if (block.BlockTypeId == BlockType.BlockContainerBlockTypeId) {
                        BlockUserControl.DeleteBlockContainer(dc, block.BlockId, new List<int>() { block.BlockId });
                    }
                    string newData = ResolveData(dc, b.Text, true);
                    block.Data = Utils.ConverToXElement(newData);
                }
                dc.SubmitChanges();
            }
            section.ParentThemes = theme;
        }

        XmlDocument themeConfig = WebUtils.LoadThemeConfigXml(theme);
        foreach (var elm in section.Colors) {
            string xpath = string.Format("ColorTemplates/ColorTemplate[@name='{0}']/Color[@name='{1}']",
                lstColorTemplates.SelectedItem.Text, elm.Name);
            elm.Value = themeConfig.DocumentElement.SelectSingleNode(xpath).InnerText;
        }
    }

    protected void mdpConfirmDataLost_OkClick(object sender, EventArgs e) {
        OnDataLostConfirmed(e);
    }

    protected virtual void OnDataLostConfirmed(EventArgs e) {
        if (null != DataLostConfirmed) {
            DataLostConfirmed(this, e);
        }
    }

    public bool CheckDataLost() {
        UIConfigurationSection section = UIConfigurationSection.GetSection();
        string theme = lstThemes.SelectedItem.Text;
        if (section.ParentThemes != theme) {
            using (DSCDataContext dc = DBController.GetDataContext()) {
                foreach (var b in GetBlocks(section.ParentThemes)) {
                    Block block = Block.GetByName(b.Name);
                    string existingData = null == block.Data ? null : RemoveSpaces(block.Data.ToString());
                    string newData = RemoveSpaces(ResolveData(dc, b.Text, false));
                    if (!newData.Equals(existingData, StringComparison.OrdinalIgnoreCase)) {
                        mdpConfirmDataLost.Show();
                        return true;
                    }
                }
            }
        }
        OnDataLostConfirmed(new EventArgs());
        return false;
    }

    private string RemoveSpaces(string s) {
        return Regex.Replace(s, "\\s", "", RegexOptions.Singleline);
    }

    private List<BlockConfiguration> GetBlocks(string theme) {
        XDocument configXml = XDocument.Load(WebUtils.GetThemeConfigXmlFilespec(theme));
        var blocks = from b in configXml.Descendants("Blocks").Descendants("Block")
                     select new BlockConfiguration {
                         Name = b.Attribute("name").Value,
                         Text = b.Value
                     };
        return blocks.ToList();
    }

    private string ResolveData(DSCDataContext dc, string data, bool createBlocks) {
        string covertedData = data;
        foreach (Match m in Regex.Matches(data,
            string.Format("{0}(?<type>Block(Type|Ref)):(?<name>[\\w ]+){0}", Constant.UI.ControlToken),
            RegexOptions.Singleline | RegexOptions.IgnoreCase)) {
            string type = m.Groups["type"].Value;
            string name = m.Groups["name"].Value;
            switch (type.ToLower()) {
                case "blocktype": {
                        int id = 0;
                        if (createBlocks) {
                            using (DSCDataContext locDC = DBController.GetDataContext()) {
                                BlockType blockType = locDC.BlockTypes.Single(bt => bt.Type == name);
                                Block newBlock = new Block() {
                                    BlockTypeId = blockType.BlockTypeId,
                                };
                                locDC.Blocks.InsertOnSubmit(newBlock);
                                locDC.SubmitChanges();
                                id = newBlock.BlockId;
                            }
                        } else {
                            try {
                                var blockId = from b in dc.Blocks
                                              join bt in dc.BlockTypes on b.BlockTypeId equals bt.BlockTypeId
                                              where bt.Type == name
                                              select b.BlockId;
                                id = blockId.Take(1).Single();
                            } catch (System.InvalidOperationException) {
                                // don't replace when not found
                            }
                        }
                        if (id > 0)
                            covertedData = covertedData.Replace(string.Format("{0}{1}:{2}{0}", Constant.UI.ControlToken, type, name),
                                string.Format("{0}{1}{0}", Constant.UI.ControlToken, id));
                    }
                    break;
                case "blockref": {
                        int id = 0;
                        try {
                            var blockId = from bf in dc.BlockReferences
                                          where bf.Name == name
                                          select bf.BlockId;
                            id = blockId.Single();
                        } catch (System.InvalidOperationException) {
                            if (createBlocks) {
                                //Todo: create block ref???
                            }
                        }
                        if (id > 0)
                            covertedData = covertedData.Replace(string.Format("{0}{1}:{2}{0}", Constant.UI.ControlToken, type, name),
                                string.Format("{0}{1}{0}", Constant.UI.ControlToken, id));
                    }
                    break;
            }
        }
        return covertedData;
    }

    protected void lstThemes_DataBound(object sender, EventArgs e) {
        UIConfigurationSection section = UIConfigurationSection.GetSection();
        foreach (ListItem item in lstThemes.Items) {
            if (item.Text == section.ParentThemes) {
                item.Selected = true;
                imgTheme.ImageUrl = item.Value;
                LoadColorTemplate(item.Text);
                break;
            }
        }
    }

    protected void lstThemes_SelectedIndexChanged(object sender, EventArgs e) {
        imgTheme.ImageUrl = lstThemes.SelectedValue;
        LoadColorTemplate(lstThemes.SelectedItem.Text);
    }

    private void LoadColorTemplate(string theme) {
        lstColorTemplates.Items.Clear();
        XmlDocument themeConfig = WebUtils.LoadThemeConfigXml(theme);
        foreach (XmlNode node in themeConfig.DocumentElement.SelectNodes("ColorTemplates/ColorTemplate")) {
            ListItem item = new ListItem(node.Attributes["name"].Value, WebUtils.GetThemeThumbnailImageUrl(theme, node.Attributes["thumbnail"].Value));
            lstColorTemplates.Items.Add(item);
        }
        lstColorTemplates.SelectedIndex = 0;
    }

    protected class BlockConfiguration {
        public string Name {get; set; }
        public string Text {get; set; }
    }
}
