//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Reflection;
using System.Linq;

using DotShoppingCart.OpenSource.Core;
using Common = DotShoppingCart.OpenSource.Core;

public partial class Admin_Controls_ProviderConfiguration : ValidatableUserControl {
    private DSCProvider provider;
    private string sectionName;

    public DSCProvider Provider {
        get { return provider; }
        set { provider = value; }
    }
    public string SectionName {
        get { return sectionName; }
        set { sectionName = value; }
    }
    private List<ProviderAttribute> attributes {
        get { return (List<ProviderAttribute>)ViewState["attributes"]; }
        set { ViewState["attributes"] = value; }
    }

    private string validationGroup;
    public override string ValidationGroup {
        set { validationGroup = value; }
    }

    private string errorMessagePrefix;
    public override string ErrorMessagePrefix {
        set { errorMessagePrefix = value; }
    }

    public Dictionary<string, string> GetSettings() {
        Dictionary<string, string> settings = new Dictionary<string, string>();
        foreach (RepeaterItem item in rptAttributes.Items) {
            Panel pnlValue = (Panel)item.FindControl("pnlValue");
            Control c = pnlValue.FindControl("chkValue");
            if (null != c)
                settings.Add(attributes[item.ItemIndex].Name, ((CheckBox)c).Checked.ToString());
            else if (null != (c = pnlValue.FindControl("txtValue")))
                settings.Add(attributes[item.ItemIndex].Name, ((TextBox)c).Text);
            else if (null != (c = pnlValue.FindControl("fulValue"))) {
                FileUpload ful = (FileUpload)c;
                if (ful.HasFile) {
                    HttpPostedFile uploadedFile = ful.PostedFile;
                    int binaryId = Binary.Add(Common.Utils.GetData(uploadedFile.InputStream), ful.FileName);
                    settings.Add(attributes[item.ItemIndex].Name, binaryId.ToString());
                }
            } else if (null != (c = pnlValue.FindControl("cusValue"))) {
                CustomUserControl customerControl = (CustomUserControl)c;
                settings.Add(attributes[item.ItemIndex].Name, customerControl.ConfiguredValue);
            } else if (null != (c = pnlValue.FindControl("cblValue"))) {
                CheckBoxList cbl = (CheckBoxList)c;
                List<string> enabled = new List<string>();
                foreach (ListItem li in cbl.Items) {
                    if (li.Selected)
                        enabled.Add(li.Value);
                }
                settings.Add(attributes[item.ItemIndex].Name, string.Join(Constant.DB.ListSeparator.ToString(), enabled.ToArray()));
            }
            //else error?

            //Todo: need to block empty shipping method and validate sort order value
        }
        return settings;
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (IsPostBack && (null != attributes)) {
            //create dynamic controls
            foreach (RepeaterItem item in rptAttributes.Items) {
                LoadControl(false, item, attributes[item.ItemIndex]);
            }
        }
    }

    public override void DataBind() {
        base.DataBind();

        if (null != provider) {
            ServiceConfigurationSection scs = (ServiceConfigurationSection)ConfigurationController.SiteConfigurationController.GetSection(sectionName);
            ProviderSettings ps = (null == scs) ? null : scs.Providers[provider.Name];

            attributes = new List<ProviderAttribute>();
            foreach (ProviderAttribute attribute in provider.GetConfigurationSettings()) {
                string configuredValue = (null == ps) ? null : ps.Parameters[attribute.Name];
                attribute.Value = configuredValue;
                attributes.Add(attribute);
            }
            rptAttributes.DataSource = attributes;
            rptAttributes.DataBind();
        }
    }

    protected void rptAttributes_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        LoadControl(true, e.Item, (ProviderAttribute)e.Item.DataItem);
    }

    private void LoadControl(bool bind, RepeaterItem item, ProviderAttribute pa) {
        Panel pnlValue = (Panel)item.FindControl("pnlValue");
        TextBox tb;
        switch (pa.Type) {
            case ConfigurationValueType.Boolean:
                CheckBox cb = new CheckBox();
                cb.ID = "chkValue";
                if (bind)
                    cb.Checked = string.IsNullOrEmpty(pa.Value) ? false : bool.Parse(pa.Value);
                pnlValue.Controls.Add(cb);
                break;
            case ConfigurationValueType.String:
                tb = new TextBox();
                tb.ID = "txtValue";
                if (bind)
                    tb.Text = pa.Value;
                tb.Width = new Unit(400);
                pnlValue.Controls.Add(tb);
                if (pa.IsRequired && string.IsNullOrEmpty(pa.Value)) { 
                    //required when the initial value is empty because the value is only updated when value is not empty during saving
                    AddRequiredFieldValidator(pnlValue, tb.ID, pa);
                }
                break;
            case ConfigurationValueType.Password:
                tb = new TextBox();
                tb.TextMode = TextBoxMode.Password;
                tb.ID = "txtValue";
                if (bind)
                    tb.Text = pa.Value;
                tb.Width = new Unit(400);
                pnlValue.Controls.Add(tb);
                if (pa.IsRequired && string.IsNullOrEmpty(pa.Value)) {
                    AddRequiredFieldValidator(pnlValue, tb.ID, pa);
                }
                break;
            case ConfigurationValueType.File:
                string binaryId = pa.Value;
                Label l = new Label();
                l.ID = "lblUploaded";
                if (bind && (!string.IsNullOrEmpty(binaryId)))
                    l.Text = string.Format("Uploaded ({0}) ", binaryId);
                pnlValue.Controls.Add(l);
                FileUpload fu = new FileUpload();
                fu.ID = "fulValue";
                fu.Width = new Unit(325);
                pnlValue.Controls.Add(fu);
                if (pa.IsRequired && string.IsNullOrEmpty(pa.Value)) {
                    AddRequiredFieldValidator(pnlValue, fu.ID, pa);
                }
                break;
            case ConfigurationValueType.CustomType:
                //Todo: the custom type should be contained in the provider. 
                //I put it as a user control as a temporary solution.
                CustomUserControl c = (CustomUserControl)LoadControl(pa.ControlType);
                c.ID = "cusValue";
                c.ConfiguredValue = pa.Value;
                pnlValue.Controls.Add(c);
                if (bind)
                    c.DataBind();
                break;
            case ConfigurationValueType.ShippingMethodConfig:
                CheckBoxList cbl = new CheckBoxList();
                cbl.ID = "cblValue";
                cbl.DataTextField = "Name";
                cbl.DataValueField = "Name";
                pnlValue.Controls.Add(cbl);
                if (bind) {
                    MethodInfo info = Provider.GetType().GetMethod("GetAllShippingMethodNames", BindingFlags.Public | BindingFlags.Instance);
                    List<string> allMethods = (List<string>)info.Invoke(Provider, null);
                    cbl.DataSource = from m in allMethods
                                     select new {
                                         Name = m
                                     };
                    cbl.DataBind();
                    string[] enabledMethods = string.IsNullOrEmpty(pa.Value) ? allMethods.ToArray() : pa.Value.Split(Constant.DB.ListSeparator);
                    foreach (ListItem li in cbl.Items) {
                        li.Selected = enabledMethods.Contains(li.Value);
                    }
                }
                break;
        }
    }

    private void AddRequiredFieldValidator(Panel container, string controlToValidate, ProviderAttribute pa) {
        RequiredFieldValidator rfv = new RequiredFieldValidator();
        rfv.ID = "rfv";
        rfv.ControlToValidate = controlToValidate;
        rfv.ValidationGroup = validationGroup;
        rfv.ErrorMessage = errorMessagePrefix + pa.DisplayName + " is a required field.";
        rfv.Text = "*";
        container.Controls.Add(rfv);
    }
}
