//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Shipping;

public partial class Admin_Controls_TableBasedShippingRate : ValidatableUserControl {
    private SortedList<decimal, decimal> rates;
    private string validationGroup;
    private int count = 0;
    private Dictionary<decimal, int> rangeValues = null;

    public RateTarget Target {
        get { return (RateTarget)ViewState["Target"]; }
        set { ViewState["Target"] = value; }
    }

    public SortedList<decimal, decimal> Rates {
        get { return GetRatesFromControls(); }
        set { rates = value; }
    }

    public override string ValidationGroup {
        set {
            base.ValidationGroup = value;
            validationGroup = value;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!Page.IsPostBack) {
            if (null == rates) {
                List<TableBasedShippingRateRange> ranges = new List<TableBasedShippingRateRange>();
                ranges.Add(new TableBasedShippingRateRange("0", "Up", string.Empty));
                BindControls(ranges);
            } else 
                BindControls();
        }
    }

    private void BindControls() {
        count = rates.Count;
        rptBulkEdit.DataSource = TableBasedShippingRateRange.ConvertToRateRanges(rates);
        rptBulkEdit.DataBind();
    }

    private void BindControls(List<TableBasedShippingRateRange> ranges) {
        count = ranges.Count;
        rptBulkEdit.DataSource = ranges;
        rptBulkEdit.DataBind();
    }

    protected void rptBulkEdit_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        string weightUnit = StoreConfigurationSection.GetSection().ProductWeightUnit;
        TableBasedShippingRateRange range = (TableBasedShippingRateRange)e.Item.DataItem;
        Label lblFrom = (Label)e.Item.FindControl("lblFrom");
        lblFrom.Text = range.Min;

        Label lblToPrefix = (Label)e.Item.FindControl("lblToPrefix");
        Label lblToSuffix = (Label)e.Item.FindControl("lblToSuffix");
        Label lblFromPrefix = (Label)e.Item.FindControl("lblFromPrefix");
        Label lblFromSuffix = (Label)e.Item.FindControl("lblFromSuffix");
        if (RateTarget.TotalOrderAmount == Target) {
            lblFromPrefix.Text = lblToPrefix.Text = "$";
        } else {
            lblFromSuffix.Text = lblToSuffix.Text = weightUnit;
        }
       
        Controls_DecimalTextBox dtbTo = (Controls_DecimalTextBox)e.Item.FindControl("dtbTo");
        dtbTo.Text = range.Max;
        dtbTo.ValidationGroup = validationGroup;
        Controls_DecimalTextBox dtbRate = (Controls_DecimalTextBox)e.Item.FindControl("dtbRate");
        dtbRate.Text = range.Value;
        dtbRate.ValidationGroup = validationGroup;
        CustomValidator cvdUniqueRate = (CustomValidator)e.Item.FindControl("cvdUniqueRate");
        cvdUniqueRate.ValidationGroup = validationGroup;

        Button btnDelete = (Button)e.Item.FindControl("btnDelete");
        if (e.Item.ItemIndex == count - 1) { //last one
            btnDelete.Visible = false;
            dtbTo.Visible = false;
            Label lblTo = (Label)e.Item.FindControl("lblTo");
            lblTo.Visible = true;
            lblTo.Text = range.Max;
            lblToSuffix.Text  = lblToPrefix.Text = string.Empty;
        } else {
            btnDelete.CommandArgument = e.Item.ItemIndex.ToString();
        }
    }

    protected void cvdUniqueRate_ServerValidate(object source, ServerValidateEventArgs args) {
        Controls_DecimalTextBox dtbTo;
        decimal value;
        if (null == rangeValues) {
            rangeValues = new Dictionary<decimal, int>();
            foreach (RepeaterItem item in rptBulkEdit.Items) {
                dtbTo = (Controls_DecimalTextBox)item.FindControl("dtbTo");
                if (!string.IsNullOrEmpty(dtbTo.Text) && (decimal.TryParse(dtbTo.Text, out value))) {
                    if (rangeValues.ContainsKey(value))
                        rangeValues[value]++;
                    else
                        rangeValues.Add(value, 1);
                }
            }
        }
        dtbTo = (Controls_DecimalTextBox)((Control)source).NamingContainer.FindControl("dtbTo");
        if (!string.IsNullOrEmpty(dtbTo.Text) && (decimal.TryParse(dtbTo.Text, out value))) {
            args.IsValid = rangeValues[value] <= 1;
        } else
            args.IsValid = true;
    }

    private SortedList<decimal, decimal> GetRatesFromControls() {
        SortedList<decimal, decimal> rates = new SortedList<decimal, decimal>();
        string prevTo = null;
        bool first = true;
        foreach (RepeaterItem item in rptBulkEdit.Items) {
            Controls_DecimalTextBox dtbTo = (Controls_DecimalTextBox)item.FindControl("dtbTo");
            Controls_DecimalTextBox dtbRate = (Controls_DecimalTextBox)item.FindControl("dtbRate");
            if (first) {
                rates.Add(0, decimal.Parse(dtbRate.Text));
                first = false;
            } else {
                rates.Add(decimal.Parse(prevTo), decimal.Parse(dtbRate.Text));
            }
            prevTo = dtbTo.Text;
        }
        return rates;
    }

    private List<TableBasedShippingRateRange> GetRangesFromControls() {
        List<TableBasedShippingRateRange> ranges = new List<TableBasedShippingRateRange>();
        string prevTo = null;
        foreach (RepeaterItem item in rptBulkEdit.Items) {
            Label lblFrom = (Label)item.FindControl("lblFrom");
            Controls_DecimalTextBox dtbTo = (Controls_DecimalTextBox)item.FindControl("dtbTo");
            Controls_DecimalTextBox dtbRate = (Controls_DecimalTextBox)item.FindControl("dtbRate");
            if (null != prevTo)
                lblFrom.Text = prevTo;
            ranges.Add(new TableBasedShippingRateRange(lblFrom.Text, dtbTo.Text, dtbRate.Text));
            prevTo = dtbTo.Text;
        }
        return ranges;
    }

    protected void btnDelete_Command(object sender, CommandEventArgs e) {
        int index = int.Parse(e.CommandArgument.ToString());
        List<TableBasedShippingRateRange> ranges = GetRangesFromControls();
        ranges.RemoveAt(index);
        if (0 == index)
            ranges[0].Min = "0";
        BindControls(ranges);
    }

    protected void btnAddRow_Click(object sender, EventArgs e) {
        List<TableBasedShippingRateRange> ranges = GetRangesFromControls();
        string rateFrom = ranges[ranges.Count - 1].Min;
        ranges[ranges.Count - 1].Min = string.Empty;
        ranges.Insert(ranges.Count - 1, new TableBasedShippingRateRange(rateFrom, string.Empty, string.Empty));
        BindControls(ranges);
    }
}

