//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;
using System.IO;
using System.Runtime.Serialization.Formatters.Binary;

using DotShoppingCart.OpenSource.Tax;
using DotShoppingCart.OpenSource.Core;

public partial class Admin_Controls_TableBasedTaxConfiguration : CustomUserControl {
    private List<TableBasedTaxRate> TableBasedTaxRates {
        get { return (List<TableBasedTaxRate>)ViewState["TableBasedTaxRates"]; }
        set { ViewState["TableBasedTaxRates"] = value; }
    }
    public override string NewConfiguredValue {
        get { return TableBasedTaxProvider.SerializeTaxRates(TableBasedTaxRates); }
    }

    protected void Page_Load(object sender, EventArgs e) {
    }

    public override void DataBind() {
        base.DataBind();
        if (null != base.configuredValue) {
            TableBasedTaxRates = TableBasedTaxProvider.DeSerializeTaxRates(base.configuredValue);
            BindControl();
        }
    }

    private void BindControl() {
        gvwTaxRates.DataSource = TableBasedTaxRates;
        gvwTaxRates.DataBind();
    }

    protected string GetConditionString(List<Condition> conditions) {
        if (null == conditions)
            return string.Empty;
        StringBuilder sb = new StringBuilder();
        foreach (Condition conditon in conditions) {
            if (sb.Length > 0)
                sb.Append(", ");
            sb.Append(conditon.Property + " " + conditon.ConditionOperator.ToString() + " " + conditon.Value);
        }
        return sb.ToString();
    }

    protected void gvwTaxRates_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        TableBasedTaxRates.RemoveAt(e.RowIndex);
        TableBasedTaxProvider.SaveTaxRates(TableBasedTaxRates);
        BindControl();
    }

    protected void gvwTaxRates_RowEditing(object sender, GridViewEditEventArgs e) {
        gvwTaxRates.SelectedIndex = e.NewEditIndex;
        
    }

    protected void gvwTaxRates_RowDataBound(object sender, GridViewRowEventArgs e) {
        Button btnEdit = (Button)e.Row.FindControl("btnEdit");
        if (null != btnEdit) {
            btnEdit.OnClientClick = string.Format("javascript:window.location.href=\"{0}?index={1}\";return false;", SiteNavigation.TaxRegionEditPage, e.Row.DataItemIndex);
        }
    }
}
