//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.IO;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Payment;
using DotShoppingCart.OpenSource.Core;

public partial class Admin_Configuration_Payment : DSCPage {
    protected void Page_Load(object sender, EventArgs e) {
        // hard coded payment methods that need site checkout support such as Paypal standard and google checkout etc
        creditCardProviderConfiguration.SectionName = CreditCardPaymentServiceConfigurationSection.SectionName;
        paypalExpressProviderConfiguration.SectionName = PaypalExpressPaymentServiceConfigurationSection.SectionName;
        paypalStandardProviderConfiguration.SectionName = PaypalStandardPaymentServiceConfigurationSection.SectionName;
        if (!IsPostBack) {
            InitControls();
        }
    }

    private void InitControls() {
        InitCreditCardControls();
        InitPaypalExpressControls();
        InitPaypalStandardControls();
    }

    private void InitCreditCardControls() {
        List<CreditCardType> cardTypes = CreditCardType.GetAll(false);
        cblCardTypes.DataSource = cardTypes;
        cblCardTypes.DataBind();
        // preset checked values in checkboxlist
        foreach (CreditCardType type in cardTypes) {
            cblCardTypes.Items.FindByValue(type.CreditCardTypeId.ToString()).Selected = type.Enabled;
        }

        ddlCreditCardProvider.Items.Clear();
        CreditCardPaymentServiceConfigurationSection pcs = (CreditCardPaymentServiceConfigurationSection)
            ConfigurationController.SiteConfigurationController.GetSection(CreditCardPaymentServiceConfigurationSection.SectionName);
        foreach (Type t in Utils.GetProviders("*Payment*.dll", typeof(CreditCardPaymentProvider))) {
            object classInstance = Activator.CreateInstance(t);
            CreditCardPaymentProvider provider = (CreditCardPaymentProvider)classInstance;
            string name = provider.Name;
            ListItem item = new ListItem(name, name);
            if (provider is NullCreditCardPaymentProvider)
                ddlCreditCardProvider.Items.Insert(0, item); // make sure NullCreditCardPaymentProvider appear first
            else
                ddlCreditCardProvider.Items.Add(item);
            if ((null != pcs) && (name == pcs.DefaultProvider)) {
                creditCardProviderConfiguration.Provider = provider;
                creditCardProviderConfiguration.DataBind();
                item.Selected = true;
            }
        }
    }

    private void InitPaypalExpressControls() {
        paypalExpressProviderConfiguration.Provider = new PaypalExpressPaymentProvider();
        paypalExpressProviderConfiguration.DataBind();
    }

    private void InitPaypalStandardControls() {
        paypalStandardProviderConfiguration.Provider = new PaypalStandardPaymentProvider();
        paypalStandardProviderConfiguration.DataBind();
    }

    protected void ddlCreditCardProvider_SelectedIndexChanged(object sender, EventArgs e) {
        creditCardProviderConfiguration.Provider = GetSelectedProvider();
        creditCardProviderConfiguration.DataBind();
    }

    private CreditCardPaymentProvider GetSelectedProvider() {
        foreach (Type t in Utils.GetProviders("*Payment*.dll", typeof(CreditCardPaymentProvider))) {
            object classInstance = Activator.CreateInstance(t);
            CreditCardPaymentProvider provider = (CreditCardPaymentProvider)classInstance;
            if (provider.Name == ddlCreditCardProvider.SelectedValue) {
                return provider;
            }
        }
        throw new ApplicationException("Internal Error: cannot find the selected credit card payment provider");
    }

    protected void btnUpdateCreditCard_Click(object sender, EventArgs e) {
        // save credit card types accepted
        foreach (ListItem item in cblCardTypes.Items) {
            CreditCardType.Update(int.Parse(item.Value), item.Selected);
        }

        Dictionary<string, string> settings = creditCardProviderConfiguration.GetSettings();
        CreditCardPaymentServiceConfigurationSection pcs = (CreditCardPaymentServiceConfigurationSection)ConfigurationController.SiteConfigurationController.GetSection(CreditCardPaymentServiceConfigurationSection.SectionName);
        if (null == pcs)
            pcs = new CreditCardPaymentServiceConfigurationSection();

        CreditCardPaymentProvider provider = GetSelectedProvider();
        ProviderSettings ps = new ProviderSettings(provider.Name, provider.GetType().AssemblyQualifiedName);
        if (null == pcs.Providers[provider.Name])
            pcs.Providers.Add(ps);

        foreach (string key in settings.Keys) {
            if (!string.IsNullOrEmpty(settings[key]))
                pcs.Providers[provider.Name].Parameters[key] = settings[key];
        }
        pcs.DefaultProvider = provider.Name;
        ConfigurationController.SiteConfigurationController.SaveSection(CreditCardPaymentServiceConfigurationSection.SectionName, pcs);
        InitControls();
        tlbStatus.ShowText("Saved");
    }

    protected void btnUpdatePaypalExpress_Click(object sender, EventArgs e) {
        Dictionary<string, string> settings = paypalExpressProviderConfiguration.GetSettings();
        PaypalExpressPaymentServiceConfigurationSection pcs = (PaypalExpressPaymentServiceConfigurationSection)
            ConfigurationController.SiteConfigurationController.GetSection(PaypalExpressPaymentServiceConfigurationSection.SectionName);
        if (null == pcs)
            pcs = new PaypalExpressPaymentServiceConfigurationSection();

        PaypalExpressPaymentProvider provider = new PaypalExpressPaymentProvider();
        ProviderSettings ps = new ProviderSettings(provider.Name, provider.GetType().AssemblyQualifiedName);
        if (null == pcs.Providers[provider.Name])
            pcs.Providers.Add(ps);

        foreach (string key in settings.Keys) {
            if (!string.IsNullOrEmpty(settings[key]))
                pcs.Providers[provider.Name].Parameters[key] = settings[key];
        }
        pcs.DefaultProvider = provider.Name;

        ConfigurationController.SiteConfigurationController.SaveSection(PaypalExpressPaymentServiceConfigurationSection.SectionName, pcs);
        tlbStatus.ShowText("Saved");
    }


    protected void btnUpdatePaypalStandard_Click(object sender, EventArgs e) {
        Dictionary<string, string> settings = paypalStandardProviderConfiguration.GetSettings();
        PaypalStandardPaymentServiceConfigurationSection pcs = (PaypalStandardPaymentServiceConfigurationSection)
            ConfigurationController.SiteConfigurationController.GetSection(PaypalStandardPaymentServiceConfigurationSection.SectionName);
        if (null == pcs)
            pcs = new PaypalStandardPaymentServiceConfigurationSection();

        PaypalStandardPaymentProvider provider = new PaypalStandardPaymentProvider();
        ProviderSettings ps = new ProviderSettings(provider.Name, provider.GetType().AssemblyQualifiedName);
        if (null == pcs.Providers[provider.Name])
            pcs.Providers.Add(ps);

        foreach (string key in settings.Keys) {
            if (!string.IsNullOrEmpty(settings[key]))
                pcs.Providers[provider.Name].Parameters[key] = settings[key];
        }
        pcs.DefaultProvider = provider.Name;

        ConfigurationController.SiteConfigurationController.SaveSection(PaypalStandardPaymentServiceConfigurationSection.SectionName, pcs);
        tlbStatus.ShowText("Saved");
    }
}
