//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Admin_User_Roles : DSCPage {
    private bool editMode = false;

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            BindControls();
        }
    }

    private void BindControls() {
        lblRoleMessage.Text = editMode ? "Update Role" : "Add a New Role";
        btnAdd.Text = editMode ? "Update" : "Add";
        btnCancel.Visible = editMode;
        txtRoleName.Enabled = !editMode;
        gvwRoles.DataSource = DSCRole.GetAll();
        gvwRoles.DataBind();
    }

    protected void gvwRoles_RowDataBound(object sender, GridViewRowEventArgs e) {
        if (e.Row.RowType == DataControlRowType.DataRow) {
            Button btnEdit = (Button)e.Row.FindControl("btnEdit");
            Button btnDelete = (Button)e.Row.FindControl("btnDelete");
            btnEdit.Enabled = btnDelete.Enabled = !editMode;
        }
    }

    protected void gvwRoles_RowEditing(object sender, GridViewEditEventArgs e) {
        string roleName = (string)gvwRoles.DataKeys[e.NewEditIndex]["Name"];
        DSCRole role = DSCRole.Get(roleName);
        txtRoleName.Text = role.Name;
        dtbDiscount.Text = role.DiscountRate.ToString();
        dtbMinOrderAmount.Text = role.MinOrderAmount.ToString();
        editMode = true;
        BindControls();
    }

    protected void gvwRoles_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        string roleName = (string)gvwRoles.DataKeys[e.RowIndex]["Name"];
        DSCRole.Delete(roleName);
        Roles.DeleteRole(roleName);
        BindControls();
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        editMode = false;
        ClearRoleInput();
        BindControls();
    }

    private void ClearRoleInput() {
        txtRoleName.Text = dtbDiscount.Text = dtbMinOrderAmount.Text = string.Empty;
    }

    protected void btnAdd_Click(object sender, EventArgs e) {
        if (IsValid) {
            if ("Add" == btnAdd.Text) {
                Roles.CreateRole(txtRoleName.Text);
                DSCRole.Add(txtRoleName.Text, 
                    string.IsNullOrEmpty(dtbDiscount.Text) ? 0 : decimal.Parse(dtbDiscount.Text),
                    string.IsNullOrEmpty(dtbMinOrderAmount.Text) ? 0 : decimal.Parse(dtbMinOrderAmount.Text));
            } else
                DSCRole.Update(txtRoleName.Text,
                    string.IsNullOrEmpty(dtbDiscount.Text) ? 0 : decimal.Parse(dtbDiscount.Text),
                    string.IsNullOrEmpty(dtbMinOrderAmount.Text) ? 0 : decimal.Parse(dtbMinOrderAmount.Text));
            editMode = false;
            ClearRoleInput();
            BindControls();
        }
    }
}
