//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;
using DSC = DotShoppingCart.OpenSource.Core;

public partial class Admin_Sale_UserEdit : DSCPage {
    private int userId;
    private DSC.User user;

    private DSC.User DSCUser {
        get {
            if (null == user)
                user = DSC.User.GetUser(userId);
            return user;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        userId = Utils.GetIntParameter("uid");

        if (!IsPostBack) {
            lblUserName.Text = DSCUser.UserName;
            etxEmail.Text = Membership.GetUser(DSCUser.UserName).Email;
            address.InitialAddressToDisplay = DSCUser.Address;
            accountOptional.User = DSCUser;
            odsOrders.SelectParameters.Add("userName", DSCUser.UserName);
            lblRoles.Text = string.Join(Constant.DB.ListSeparator.ToString(), Roles.GetRolesForUser(DSCUser.UserName));
            btnEditRoles.Text = string.IsNullOrEmpty(lblRoles.Text) ? "Add Roles" : "Edit Roles";
        }
    }

    protected void btnSave_Click(object sender, EventArgs e) {
        if (IsValid) {
            MembershipUser mUser = Membership.GetUser(DSCUser.UserName);
            if (0 != string.Compare(etxEmail.Text, mUser.Email, true)) {
                mUser.Email = etxEmail.Text;
                Membership.UpdateUser(mUser);
            }

            DSC.User.UpdateUserBillingAddress(DSCUser.UserName, address.FirstName, address.LastName, address.CompanyName, address.Address, address.Address2,
                address.City, address.State, address.CountryId, address.Zipcode, address.Phone, address.PhoneExt);

            DSC.User.UpdateUserOptional(DSCUser.UserName, accountOptional.NewsLetter);

            UpdateRoles();
            tlbStatus.ShowText("Saved");
        }
    }

    private void UpdateRoles() {
        Dictionary<string, bool> newRoles = new Dictionary<string, bool>();
        foreach (string roleName in lblRoles.Text.Split(Constant.DB.ListSeparator)) {
            newRoles.Add(roleName, true);
        }
        Dictionary<string, bool> oldRoles = GetCurrentRoles();
        List<string> rolesToAdd = new List<string>();
        List<string> rolesToDelete = new List<string>();
        foreach (DSCRole role in DSCRole.GetAll()) {
            if (oldRoles.ContainsKey(role.Name) && (!newRoles.ContainsKey(role.Name))) {
                rolesToDelete.Add(role.Name);
            } else if (newRoles.ContainsKey(role.Name) && (!oldRoles.ContainsKey(role.Name))) {
                rolesToAdd.Add(role.Name);
            }
        }
        if (rolesToAdd.Count > 0)
            Roles.AddUserToRoles(DSCUser.UserName, rolesToAdd.ToArray());
        if (rolesToDelete.Count > 0)
            Roles.RemoveUserFromRoles(DSCUser.UserName, rolesToDelete.ToArray());
    }

    protected void chlRoles_DataBound(object sender, EventArgs e) {
        Dictionary<string, bool> roles = GetCurrentRoles();
        foreach (ListItem item in chlRoles.Items) {
            if (roles.ContainsKey(item.Value))
                item.Selected = true;
        }
    }

    private Dictionary<string, bool> GetCurrentRoles() {
        Dictionary<string, bool> roles = new Dictionary<string, bool>();
        foreach (string roleName in Roles.GetRolesForUser(DSCUser.UserName)) {
            roles.Add(roleName, true);
        }
        return roles;
    }

    protected void btnUpdateRole_Click(object sender, EventArgs e) {
        List<string> roles = new List<string>();
        foreach (ListItem item in chlRoles.Items) {
            if (item.Selected)
                roles.Add(item.Value);
        }
        lblRoles.Text = string.Join(Constant.DB.ListSeparator.ToString(), roles.ToArray());
        btnEditRoles.Text = string.IsNullOrEmpty(lblRoles.Text) ? "Add Roles" : "Edit Roles";
    }
}
