//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public class AddressUpdatingEventArgs : EventArgs {
    public Address AddressUpdating;

    public AddressUpdatingEventArgs(Address updating) {
        AddressUpdating = updating;
    }
}
public delegate void AddressUpdateUpdatingEventHandler(object sender, AddressUpdatingEventArgs e);

public partial class Controls_AddressUpdate : System.Web.UI.UserControl {
    private Address address;
    private Address savedAddress {
        get { return (Address)ViewState["savedAddress"]; }
        set { ViewState["savedAddress"] = value; }
    }

    public event AddressUpdateUpdatingEventHandler Updating = null;

    public Address Address {
        get { return address; }
        set { address = value; }
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (null != address) {
            BindShippingAddress();
            savedAddress = address;
        }
    }

    private void BindShippingAddress() {
        fvwShippingAddress.DataSource = new Address[] { address };
        fvwShippingAddress.DataBind();
    }

    protected void fvwShippingAddress_ModeChanging(object sender, FormViewModeEventArgs e) {
        fvwShippingAddress.ChangeMode(e.NewMode);
        if ((e.NewMode != FormViewMode.Insert) && (null == address)) 
            address = savedAddress;
    }

    protected void fvwShippingAddress_ItemUpdating(object sender, FormViewUpdateEventArgs e) {
        if (Page.IsValid) {
            Controls_AddressInput aiShippingAddress = (Controls_AddressInput)fvwShippingAddress.FindControl("aiShippingAddress");
            Address updating = new Address(aiShippingAddress.FirstName, aiShippingAddress.LastName, aiShippingAddress.CompanyName, aiShippingAddress.Address, aiShippingAddress.Address2,
                    aiShippingAddress.City, aiShippingAddress.State, aiShippingAddress.Zipcode, aiShippingAddress.CountryId, aiShippingAddress.Phone, aiShippingAddress.PhoneExt);
            OnUpdating(new AddressUpdatingEventArgs(updating));
            fvwShippingAddress.ChangeMode(FormViewMode.ReadOnly);
        }
    }

    protected virtual void OnUpdating(AddressUpdatingEventArgs e) {
        if (null != Updating) {
            Updating(this, e);
        }
    }

}
