﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_Blocks_AddBlock : System.Web.UI.UserControl {
    public string PlaceHolderName { get; set; }
    public int BlockId { get; set; }
    public Type BlockContainerType { get; set; }
    public int PageId { get; set; }

    public bool isPageRootContainer = false;
    public bool IsPageRootContainer {
        get { return isPageRootContainer; }
        set { isPageRootContainer = value; }
    }

    public Controls_Blocks_AddBlock() {
        BlockContainerType = typeof(BlockContainerData);
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (IsPageRootContainer)
            rptBlockGroups.Visible = false;
    }

    protected void btnSave_Click(object sender, EventArgs e) {
        using (DSCDataContext dc = DBController.GetDataContext()) {
            XElement x = null;
            int refBlockId = 0;
            int blockTypeId = 1; //default to block container
            bool found = false;
            foreach (ListItem item in cblBlockTemplates.Items) {
                if (item.Selected) {
                    BlockContainerTemplate t = dc.BlockContainerTemplates.Single(b => b.BlockContainerTemplateId == int.Parse(item.Value));
                    BlockContainerData newData = new BlockContainerData();
                    newData.Content = t.TemplateContent;
                    x = newData.ToXElement();
                    found = true;
                    break;
                }
            }

            if (!found) {
                foreach (ListItem item in cblBlockReferences.Items) {
                    if (item.Selected) {
                        BlockReference br = dc.BlockReferences.Single(b => b.BlockId == int.Parse(item.Value));
                        br.RefCount++;
                        refBlockId = br.BlockId;
                        found = true;
                        break;
                    }
                }
            }

            if (!found) {
                foreach (RepeaterItem ri in rptBlockGroups.Items) {
                    CheckBoxList cblStandardBlocks = (CheckBoxList)ri.FindControl("cblStandardBlocks");
                    foreach (ListItem item in cblStandardBlocks.Items) {
                        if (item.Selected) {
                            blockTypeId = int.Parse(item.Value);
                            found = true;
                            break;
                        }
                    }
                }
            }

            if (found) {
                int newBlockId = 0;
                if (refBlockId == 0) {
                    Block newBlock = new Block();
                    newBlock.BlockTypeId = blockTypeId;
                    newBlock.Data = x;
                    dc.Blocks.InsertOnSubmit(newBlock);
                    dc.SubmitChanges();
                    newBlockId = newBlock.BlockId;
                } else {
                    newBlockId = refBlockId;
                }

                if (IsPageRootContainer) {
                    // Update the page
                    DbPage page = dc.DbPages.Single(p => p.PageId == PageId);
                    page.BlockId = newBlockId;
                } else {
                    //Update the parent block container content with the new block id
                    Block block = dc.Blocks.Single(b => b.BlockId == BlockId);
                    BlockContainerData data = (BlockContainerData)Utils.FromXml(BlockContainerType, block.Data.ToString());
                    data.Content = data.Content.Replace(string.Format("{0}{1}{0}", Constant.UI.ControlToken, PlaceHolderName),
                        string.Format("{0}{2}{0}{0}{1}{0}", Constant.UI.ControlToken, PlaceHolderName, newBlockId));
                    block.Data = data.ToXElement();
                }
                dc.SubmitChanges();
            }
        }
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void rptBlockGroups_ItemDataBound(object sender, RepeaterItemEventArgs e) {
        BlockTypeGroup btGroup = (BlockTypeGroup)e.Item.DataItem;
        DSCDataContext dc = DBController.GetDataContext();
        var blockTypes = from btg in dc.BlockTypeGroupBlockTypeMaps
                         join bt in dc.BlockTypes on btg.BlockTypeId equals bt.BlockTypeId
                         where btg.BlockTypeGroupId == btGroup.BlockTypeGroupId
                         orderby btg.SortOrder
                         select bt;
        CheckBoxList cblStandardBlocks = (CheckBoxList)e.Item.FindControl("cblStandardBlocks");
        cblStandardBlocks.DataSource = blockTypes;
        cblStandardBlocks.DataBind();
    }
}
