﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_Blocks_BlockEditor : System.Web.UI.UserControl {
    [TemplateContainer(typeof(EditContainer))]
    [PersistenceMode(PersistenceMode.InnerProperty)]
    public ITemplate EditTemplate { get; set; }

    private EditContainer container;
    public EditContainer Edit {
        get { return container; }
    }

    public BlockUserControl BlockUserControl { get; set; }

    public string BlockTitle {
        get { return lblBlockTitle.Text; }
        set { lblBlockTitle.Text = value; }
    }

    public string EditTitle {
        get { return lblEditTitle.Text; }
        set { lblEditTitle.Text = value; }
    }

    public Unit Width {
        get { return pnlEdit.Width; }
        set { pnlEdit.Width = value; }
    }

    public string ValidationGroup {
        get { return btnSave.ValidationGroup; }
        set { btnSave.ValidationGroup = value; }
    }

    public bool EditHeaderEnabled { 
        get { return btnEditHeader.Visible; }
        set { pnlEditHeaderPopup.Visible = btnEditHeader.Visible = value; }
    }

    public event EventHandler Save;
    public event EventHandler Editing;

    void Page_Init(object sender, EventArgs e) {
        if (null == EditTemplate) {
            pnlEditPopup.Visible = false;
            if (null == Editing) {
                btnEdit.Visible = false;
            } else {
                btnEdit.Click += new EventHandler(btnEdit_Click);
            }
        } else {
            container = new EditContainer();
            EditTemplate.InstantiateIn(container);
            editPlaceHolder.Controls.Add(container);
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (BlockUserControl.ShowEditor) {
            pnlShowMenu.Visible = true;
            btnMoveForward.Visible = BlockUserControl.MoveForwardEnabled;
            btnMoveBack.Visible = BlockUserControl.MoveBackEnabled;
            btnDelete.Visible = BlockUserControl.DeleteEnabled;
            btnCondition.Visible = BlockUserControl.SetConditionEnabled;
            if (null != BlockUserControl.HeaderData) {
                chkShowBlockHeader.Checked = BlockUserControl.HeaderData.Enabled;
                txtTitle.Text = BlockUserControl.HeaderData.Title;
                ntbHeaderWidth.Value = BlockUserControl.HeaderData.Width;
                ntbHeaderHeight.Value = BlockUserControl.HeaderData.Height;
            }
            ntbHeaderHeight.ValidationGroup = ntbHeaderWidth.ValidationGroup = vdsEdit.ValidationGroup = btnSaveHeader.ValidationGroup = this.ClientID;
            btnCondition.OnClientClick = string.Format("javascript:window.location.href=\"{0}?id={1}&returnurl={2}\";return false;",
                SiteNavigation.ResolveAbsoluteUrl(false, SiteNavigation.ResolveUrl("Admin/BlockConditionsEdit.aspx")), BlockUserControl.BlockId,
                Request.RawUrl);
        }
    }

    protected virtual void OnSave(EventArgs e) {
        if (null != Save) {
            Save(this, e);
        }
    }

    protected void btnSave_Click(object sender, EventArgs e) {
        OnSave(e);
    }

    protected virtual void OnEdit(EventArgs e) {
        if (null != Editing) {
            Editing(this, e);
        }
    }

    protected void btnEdit_Click(object sender, EventArgs e) {
        OnEdit(e);
    }

    protected void btnSaveHeader_Click(object sender, EventArgs e) {
        if (Page.IsValid) {
            BlockUserControl.SaveHeaderData(new BlockHeaderData() {
                Enabled = chkShowBlockHeader.Checked,
                Title = txtTitle.Text,
                Width = ntbHeaderWidth.Value,
                Height = ntbHeaderHeight.Value
            });
            Block.ClearCache();
            WebUtils.ReloadPage();
        }
    }

    protected void btnDelete_Click(object sender, EventArgs e) {
        BlockUserControl.Remove();
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnMoveForward_Click(object sender, EventArgs e) {
        BlockUserControl.MoveForward();
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnMoveBack_Click(object sender, EventArgs e) {
        BlockUserControl.MoveBack();
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    public class EditContainer : Control, INamingContainer {
        internal EditContainer() {
        }
    }
}
