﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_Blocks_ContactForm : BlockUserControl {
    protected void Page_Load(object sender, EventArgs e) {
        editor.BlockUserControl = this;
        if (ShowEditor) {
            pnlBlockContent.CssClass = "BlockEditPanel";
            editor.BlockTitle = string.Format("Contact Form {0}", BlockId);
        }

        adAddress.Address = AddressHelper.GetSiteAddress();
        adAddress.DataBind();
    }

    protected void btnSubmit_Click(object sender, EventArgs e) {
        if (Page.IsValid) {
            SiteConfigurationSection section = SiteConfigurationSection.GetSection();
            NameValueCollection tokens = Utils.GetSiteTokens();
            tokens.Add("Contact.Customer", Server.HtmlEncode(txtName.Text));
            tokens.Add("Contact.Regarding",
                string.IsNullOrEmpty(txtOrderNumber.Text) ? "" :
                "regarding to order# " + Server.HtmlEncode(txtOrderNumber.Text));
            tokens.Add("Contact.Message", Server.HtmlEncode(txtMessage.Text));

            List<string> to = new List<string>();
            to.Add(section.SiteEmailAddress);
            if (chkCopy.Checked)
                to.Add(etbEmail.Text);

            try {
                EmailManager.Send("Contact", tokens, etbEmail.Text, to);
                txtName.Text = etbEmail.Text = txtOrderNumber.Text = txtMessage.Text = string.Empty;
                chkCopy.Checked = false;
                lblStatus.CssClass = "success";
                lblStatus.Text = "Email was sent successfully";
            } catch (System.Net.Mail.SmtpException ex) {
                if (ex.Message.StartsWith("Mailbox unavailable", StringComparison.OrdinalIgnoreCase)) {
                    lblStatus.CssClass = "error";
                    lblStatus.Text = string.Format("Failed to send email. Please verify email address is correct. Or you could send email directly to {0}.",
                        section.SiteEmailAddress);
                } else throw;
            } catch (FormatException ex) {
                if (ex.Message.Equals("The specified string is not in the form required for an e-mail address.", StringComparison.OrdinalIgnoreCase)) {
                    lblStatus.CssClass = "error";
                    lblStatus.Text = "Your email address is invalid.";
                } else throw;
            }
        }
    }
}
