﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_Blocks_PageBlockContainer : BlockUserControl {
    private LinkButton btnToggleLeftMasterColumn {
        get { return (LinkButton)container.Menu.FindControl("btnToggleLeftMasterColumn"); }
    }
    private LinkButton btnToggleRightMasterColumn {
        get { return (LinkButton)container.Menu.FindControl("btnToggleRightMasterColumn"); }
    }
    private PageBlockContainerData containerData;

    public PageBlockContainerData DefaultData { get; set; }

    protected void Page_Load(object sender, EventArgs e) {
        container.BlockId = this.BlockId;
        container.DeleteEnabled = container.MoveForwardEnabled = container.MoveBackEnabled = false;
        container.Save += new BlockContainerSaveEventHandler(container_Save);
        container.BlockContainerType = typeof(PageBlockContainerData);

        if (null != Data) {
            containerData = Utils.FromXml<PageBlockContainerData>(Data.ToString());
            container.Data = new BlockContainerData() { Content = containerData.Content }.ToXElement();
            ((DSCMasterPage)Page.Master).LeftColumnVisible = !containerData.LeftMasterColumnDisabled;
            ((DSCMasterPage)Page.Master).RightColumnVisible = !containerData.RightMasterColumnDisabled;
            if (ShowEditor) {
                btnToggleLeftMasterColumn.Text = containerData.LeftMasterColumnDisabled ? "Enable Left Master Block Container" : "Disable Left Master Block Container";
                btnToggleRightMasterColumn.Text = containerData.RightMasterColumnDisabled ? "Enable Right Master Block Container" : "Disable Right Master Block Container";
            }
        }
    }

    private void container_Save(object sender, BlockContainerSaveEventArgs e) {
        containerData.Content = e.ContainerData.Content;
        SaveData(containerData.ToXElement());
    }

    protected void btnToggleLeftMasterColumn_Click(object sender, EventArgs e) {
        containerData.LeftMasterColumnDisabled = btnToggleLeftMasterColumn.Text == "Disable Left Master Block Container";
        SaveData(containerData.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnToggleRightMasterColumn_Click(object sender, EventArgs e) {
        containerData.RightMasterColumnDisabled = btnToggleRightMasterColumn.Text == "Disable Right Master Block Container";
        SaveData(containerData.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }

    protected void btnReset_Click(object sender, EventArgs e) {
        SaveData(DefaultData.ToXElement());
        Block.ClearCache();
        WebUtils.ReloadPage();
    }
}
