﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_ConditionsEditor : System.Web.UI.UserControl {
    public List<ConditionProperty> Properties { get; set; }

    private object propertiesToBind = null;
    private object PropertiesToBind {
        get {
            if (null == propertiesToBind) {
                propertiesToBind = from p in Properties
                                   select new {
                                       Name = p.Name
                                   };
            }
            return propertiesToBind;
        }
    }

    public List<Condition> Conditions {
        get { return (List<Condition>)ViewState["Conditions"]; }
        set { ViewState["Conditions"] = value; }
    }

    public string AddButtonText {
        set { btnAdd.Text = value; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            ddlProperty.DataSource = PropertiesToBind;
            ddlProperty.DataBind();
            ddlAddOperator.DataSource = Utils.GetEnumNameValueList(typeof(ConditionOperator));
            ddlAddOperator.DataBind();
            if ((null != Properties) && (Properties.Count > 0)) {
                SetValue(ddlProperty, null);
            }
            BindControls();
        }
    }

    private ConditionProperty GetSelectedProperty(string name) {
        return Properties.Single(p => p.Name == name);
    }

    protected void ddlProperty_SelectedIndexChanged(object sender, EventArgs e) {
        SetValue((DropDownList)sender, null);
    }

    public override void DataBind() {
        base.DataBind();
        BindControls();
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        pnlHeader.Visible = (null == Conditions) || (Conditions.Count == 0);
    }

    private void BindControls() {
        gvwCondition.DataSource = Conditions;
        gvwCondition.DataBind();
    }

    protected void gvwCondition_RowDataBound(object sender, GridViewRowEventArgs e) {
        if (e.Row.RowType == DataControlRowType.DataRow) {
            DropDownList ddlOperator = (DropDownList)e.Row.FindControl("ddlOperator");
            if (null != ddlOperator) {
                ddlOperator.DataSource = Utils.GetEnumNameValueList(typeof(ConditionOperator));
                ddlOperator.DataBind();
            }

            DropDownList ddlProperty = (DropDownList)e.Row.FindControl("ddlProperty");
            if (null != ddlProperty) {
                ddlProperty.DataSource = PropertiesToBind;
                ddlProperty.DataBind();
                Condition condition = (Condition)e.Row.DataItem;
                WebUtils.SetDropDownListSelected(ddlProperty, condition.Property);
                SetValue(ddlProperty, condition.Value);
            }
        }
    }

    private void SetValue(DropDownList ddl, string value) {
        MultiView mvValue = (MultiView)ddl.NamingContainer.FindControl("mvValue");
        ConditionProperty p = GetSelectedProperty(ddl.SelectedValue);
        switch (p.Type) {
            case ConditionValueType.Text:
                mvValue.ActiveViewIndex = 0;
                if (null != value) {
                    TextBox tb = (TextBox)mvValue.FindControl("txtValue");
                    tb.Text = value;
                }
                break;
            case ConditionValueType.List:
                mvValue.ActiveViewIndex = 1;
                DropDownList ddlv = (DropDownList)mvValue.FindControl("ddlValue");
                ddlv.DataSource = p.Data;
                ddlv.DataBind();
                if (null != value) {
                    WebUtils.SetDropDownListSelected(ddlv, value);
                }
                break;
        }
    }

    protected void gvwCondition_RowEditing(object sender, GridViewEditEventArgs e) {
        gvwCondition.EditIndex = e.NewEditIndex;
        pnlAdd.Visible = false;
        BindControls();
    }

    protected void gvwCondition_RowUpdating(object sender, GridViewUpdateEventArgs e) {
        DropDownList ddlProperty = (DropDownList)gvwCondition.Rows[e.RowIndex].FindControl("ddlProperty");
        DropDownList ddlOperator = (DropDownList)gvwCondition.Rows[e.RowIndex].FindControl("ddlOperator");
        MultiView mvValue = (MultiView)gvwCondition.Rows[e.RowIndex].FindControl("mvValue");

        Condition condition = Conditions[e.RowIndex];
        condition.Property = ddlProperty.SelectedValue;
        condition.ConditionOperator = (ConditionOperator)int.Parse(ddlOperator.SelectedValue);
        condition.Value = GetValue(mvValue);

        gvwCondition.EditIndex = -1;
        pnlAdd.Visible = true;
        BindControls();
    }

    protected void gvwCondition_RowCancelingEdit(object sender, GridViewCancelEditEventArgs e) {
        gvwCondition.EditIndex = -1;
        pnlAdd.Visible = true;
        BindControls();
    }

    protected void gvwCondition_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        Conditions.RemoveAt(e.RowIndex);
        BindControls();
    }

    protected void btnAdd_Click(object sender, EventArgs e) {
        if (null == Conditions)
            Conditions = new List<Condition>();
        Conditions.Add(new Condition(ddlProperty.SelectedValue, (ConditionOperator)int.Parse(ddlAddOperator.SelectedValue), GetValue(mvValue)));
        BindControls();

        //reset add form
        ddlProperty.SelectedIndex = ddlAddOperator.SelectedIndex = 0;
        SetValue(ddlProperty, null);
    }

    private string GetValue(MultiView mv) {
        switch (mv.ActiveViewIndex) {
            case 0:
                return ((TextBox)mv.FindControl("txtValue")).Text;
            case 1:
                return ((DropDownList)mv.FindControl("ddlValue")).SelectedValue;
        }
        return null;
    }
}
