﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using Microsoft.Practices.EnterpriseLibrary.ExceptionHandling;
using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Payment;
using DotShoppingCart.OpenSource.OrderTotal;

public partial class Store_Checkout : BlockUserControl {
    private PaypalExpressPaymentProvider paypalExpressProvider;
    public PaypalExpressPaymentProvider PaypalExpressProvider {
        get {
            if (null == paypalExpressProvider)
                paypalExpressProvider = PaypalExpressPaymentProvider.GetProvider();
            return paypalExpressProvider;
        }
    }

    private PaypalStandardPaymentProvider paypalStandardProvider;
    public PaypalStandardPaymentProvider PaypalStandardProvider {
        get {
            if (null == paypalStandardProvider)
                paypalStandardProvider = PaypalStandardPaymentProvider.GetProvider();
            return paypalStandardProvider;
        }
    }

    protected Address ShippingAddress {
        get { return (Address)Session["ShippingAddress"]; }
        set { Session["ShippingAddress"] = value; }
    }

    protected PaypalPaymentInfo PaypalPaymentInfoForCheckout {
        get { return (PaypalPaymentInfo)ViewState["PaypalPaymentInfoForCheckout"]; }
        set { ViewState["PaypalPaymentInfoForCheckout"] = value; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        ValidateCheckoutPrerequisite();

        if (!Page.User.Identity.IsAuthenticated)
            Response.Redirect(SiteNavigation.LoginPage + "?ReturnUrl=" + SiteNavigation.CheckoutPage);

        if (!IsPostBack) {
            string canceled = Utils.GetParameter("canceled", null);
            if (string.IsNullOrEmpty(canceled)) {
                string token = Utils.GetParameter("token", null);
                if (!string.IsNullOrEmpty(token))
                    ProcessPaypalExpressOrderConfirmation(token);
            }
        }
        pnlResult.Visible = false;
    }

    protected void Page_PreRender(object sender, EventArgs e) {
        pnlPaypalCheckout.Visible = (wzsSubmitOrder != wzdCheckout.ActiveStep) &&
            (null != PaypalExpressProvider) && PaypalExpressProvider.Enabled;

        if (wzsSubmitOrder == wzdCheckout.ActiveStep) {
            adShippingAddress.Address = ShippingAddress;
            adShippingAddress.DataBind();
            paymentSummary.CheckoutPaymentType = paymentOption.CheckoutPaymentType;
            paymentSummary.CreditCard = paymentOption.CreditCard;
            selectShippingMethod.DataBind();
            orderTotal.OrderTotals = GetOrderTotal();
            dvSelectPaymentMethod.Visible = false;
            pnlPaypalStandardPrompt.Visible = (CheckoutPaymentTypeEnum.PaypalStandard == paymentOption.CheckoutPaymentType);
        }
    }

    private void ValidateCheckoutPrerequisite() {
        Cart cart = Cart.Get();
        if ((null == cart) || cart.IsEmpty() || (!cart.ValidateStock()) ||
            (cart.InstockSubTotal < WebUtils.GetMinOrderAmount())) {
            Response.Redirect(SiteNavigation.CartPage);
        }
    }

    private void ProcessPaypalExpressOrderConfirmation(string token) {
        PaypalPayer payer = PaypalExpressProvider.GetExpressCheckout(token);
        if (!payer.IsPayerValid) //User cancelled paypal checkout
            return;
        if (payer.IsCountryValid) {
            ShippingAddress = payer.Address;
            PaypalPaymentInfoForCheckout = payer.PaypalPaymentInfo;
            paymentOption.CheckoutPaymentType = CheckoutPaymentTypeEnum.PaypalExpress;
            wzdCheckout.MoveTo(wzsSubmitOrder);
        } else {
            pnlResult.Visible = true;
            lblResult.Text = string.Format("{0} is the country from your PayPal shipping address. We currently don't ship to that country. Please contact us or use another shipping address.",
                payer.PaypalCountryName);
        }
    }

    protected void btnExpressCheck_Click(object sender, EventArgs e) {
        if (PaypalExpressProvider.Enabled) {
            try {
                string url = PaypalExpressProvider.SetExpressCheckout(
                    Cart.Get().SubTotal, SiteNavigation.CheckoutPage,
                    SiteNavigation.CheckoutPage + "?canceled=1", true);
                Response.Redirect(url);
            } catch (PaymentExecption ex) {
                OnPaypalExpressCheckoutFailed();
                ExceptionPolicy.HandleException(ex, "Unhandled Policy");
            }
        }
    }

    protected void addressManager_Selected(object sender, AddressSelectedEventArgs e) {
        ShippingAddress = e.AddressSelected;
        aiShipping.InitialAddressToDisplay = ShippingAddress;
        wzdCheckout.MoveTo(wzsBilling);
    }

    protected void btnContinue_Click(object sender, EventArgs e) {
        if (!string.IsNullOrEmpty(paymentOption.ActiveValidationGroup))
            Page.Validate(paymentOption.ActiveValidationGroup);

        if (Page.IsValid)
            wzdCheckout.MoveTo(wzsSubmitOrder);
    }

    protected void btnChangeShipping_Click(object sender, EventArgs e) {
        wzdCheckout.MoveTo(wzsShipping);
    }

    protected void btnChangePayment_Click(object sender, EventArgs e) {
        wzdCheckout.MoveTo(wzsBilling);
    }

    protected void btnChangeOrder_Click(object sender, EventArgs e) {
        Response.Redirect(SiteNavigation.CartPage);
    }

    protected void cvdShippingMethod_ServerValidate(object source, ServerValidateEventArgs args) {
        args.IsValid = null != Session["ShippingMethod"];
    }

    protected void lbtChangeIndexClick(object sender, EventArgs e) {
        LinkButton lbt = (LinkButton)sender;
        if (lbt.ID.StartsWith("lbtShipping")) {
            wzdCheckout.MoveTo(wzsShipping);
        } else {
            wzdCheckout.MoveTo(wzsBilling);
        }
    }

    protected void btnSubmitOrder_Click(object sender, EventArgs e) {
        if (!Page.IsValid)
            return;

        SubmitOrder(Membership.GetUser(Utils.GetUserName()).Email, paymentOption.CheckoutPaymentType, paymentOption.CreditCard, paymentOption.BillingAddress);
    }

    public List<OrderTotal> GetOrderTotal() {
        Cart cart = Cart.Get();
        List<OrderTotal> totals = OrderTotalService.GetOrderTotals(cart, TaxLocation.GetTaxLocation(ShippingAddress));
        return totals;
    }

    protected void SubmitOrder(string email, CheckoutPaymentTypeEnum type, CreditCard card, Address billingAddress) {
        ShippingMethod shippingMethod = (ShippingMethod)Session["ShippingMethod"];
        List<OrderTotal> orderTotals = GetOrderTotal();

        PaymentTransaction transaction = null;
        if (CheckoutPaymentTypeEnum.PaypalExpress == type) {
            try {
                transaction = PaypalExpressProvider.DoExpressCheckout(PaypalPaymentInfoForCheckout.Token, PaypalPaymentInfoForCheckout.PayerId, orderTotals[orderTotals.Count - 1].Amount, true);
            } catch (PaymentExecption ex) {
                OnPaypalExpressCheckoutFailed();
                ExceptionPolicy.HandleException(ex, "Unhandled Policy");
                return;
            }
        }

        string userName = userName = Utils.GetUserName();
        string orderNumber = null;
        try {
            int? initialOrderStatusId = null;
            if (CheckoutPaymentTypeEnum.PaypalStandard == type)
                initialOrderStatusId = Constant.DB.OrderStatusPaypalStandardAwaitingPayment;
            if (null == billingAddress)
                billingAddress = ShippingAddress;
            orderNumber = Order.Add(userName, Utils.GetUserName(), email, WebUtils.GetDiscountRate(), shippingMethod.Name, ShippingAddress, billingAddress, type, card,
                orderTotals, initialOrderStatusId);
            if (null != transaction)
                transaction.Add(orderNumber);
        } catch (Exception ex) {
            if (ex.Message.Contains("enough in stock")) { //out of stock
                Response.Redirect(SiteNavigation.CartPage);
            }
            if (CheckoutPaymentTypeEnum.PaypalExpress == type) {
                //It was authorized when doing Express checkout. Need to send notification to admin for this issue and make order as complete.
                ExceptionPolicy.HandleException(ex, "Unhandled Policy"); //Todo: need to use other policy
            } else {
                throw;
            }
        }

        if (CheckoutPaymentTypeEnum.PaypalStandard == type) {
            try {
                Response.Redirect(PaypalStandardProvider.GetUploadOrderUrl(orderNumber));
            } catch (PaymentExecption ex) {
                pnlResult.Visible = true;
                lblResult.Text = "PayPal is currently having issues accepting payment. Please use other payment methods.";
                ExceptionPolicy.HandleException(ex, "Unhandled Policy");
            }
            return;
        }

        if (!string.IsNullOrEmpty(ShippingAddress.SaveAs))
            Address.Save(ShippingAddress);

        if (CheckoutPaymentTypeEnum.CreditCard == type) {
            User.UpdateUserBillingAddress(Utils.GetUserName(), billingAddress.FirstName, billingAddress.LastName, billingAddress.CompanyName, billingAddress.Address1, billingAddress.Address2,
                billingAddress.City, billingAddress.State, billingAddress.CountryId, billingAddress.Zipcode, billingAddress.Phone, billingAddress.PhoneExt);

            if ((null != card) && (!string.IsNullOrEmpty(card.SaveAs)))
                CreditCard.Save(card);
        }

        Response.Redirect(SiteNavigation.CheckoutCompletePage);
    }

    private void OnPaypalExpressCheckoutFailed() {
        pnlResult.Visible = true;
        lblResult.Text = "PayPal is currently having issues accepting payment. Please use other payment methods.";
        wzdCheckout.MoveTo(wzsShipping);
    }
}
