//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_CreditCardManager : System.Web.UI.UserControl {
    private bool editMode {
        get {
            object o = ViewState["editMode"];
            if (null == o)
                return false;
            return (bool)o;
        }

        set { ViewState["editMode"] = value; }
    }

    private int creditCardIdForEdit {
        get { return (int)ViewState["creditCardIdForEdit"]; }
        set { ViewState["creditCardIdForEdit"] = value; }
    }
    
    protected void Page_PreRender(object sender, EventArgs e) {
        if (!IsPostBack)
            BindExistingCreditCards();
    }

    private void BindExistingCreditCards() {
        gvwExistingCreditCards.DataSource = CreditCard.Get();
        gvwExistingCreditCards.DataBind();
    }

    protected void gvwExistingCreditCards_RowDeleting(object sender, GridViewDeleteEventArgs e) {
        int creditCardId = (int)gvwExistingCreditCards.DataKeys[e.RowIndex]["CreditCardId"];
        CreditCard.Delete(creditCardId);
        BindExistingCreditCards();
    }

    protected void gvwExistingCreditCards_RowEditing(object sender, GridViewEditEventArgs e) {
        int creditCardId = (int)gvwExistingCreditCards.DataKeys[e.NewEditIndex]["CreditCardId"];
        CreditCard creditCard = CreditCard.Get(creditCardId);
        creditCardInput.CreditCard = creditCard;
        creditCardInput.DataBind();
        creditCardIdForEdit = creditCardId;
        SetEditMode(true);
    }

    protected void btnDelete_Command(object sender, CommandEventArgs e) {
        int creditCardId = int.Parse(e.CommandArgument.ToString());
        CreditCard.Delete(creditCardId);
        BindExistingCreditCards();
    }
    
    protected void btnAdd_Click(object sender, EventArgs e) {
        if (Page.IsValid) {
            if (editMode) {
                CreditCard.Update(creditCardIdForEdit, creditCardInput.SaveAs, creditCardInput.CardTypeId, creditCardInput.CardNumber, creditCardInput.CardholderName,
                    creditCardInput.ExpireYear, creditCardInput.ExpireMonth, creditCardInput.CVV2, creditCardInput.Phone);
                SetEditMode(false);
            } else {
                int creditCardId = CreditCard.Add(creditCardInput.SaveAs, creditCardInput.CardTypeId, creditCardInput.CardNumber, creditCardInput.CardholderName,
                    creditCardInput.ExpireYear, creditCardInput.ExpireMonth, creditCardInput.CVV2, creditCardInput.Phone);
            }

            creditCardInput.Clear();
            BindExistingCreditCards();
        }
    }

    private void SetEditMode(bool edit) {
        if (edit) {
            gvwExistingCreditCards.Enabled = false;
            editMode = true;
            btnCancel.Visible = true;
            btnAdd.Text = "Update";
        } else {
            gvwExistingCreditCards.Enabled = true;
            editMode = false;
            btnCancel.Visible = false;
            btnAdd.Text = "Add";
            creditCardIdForEdit = 0;
        }
    }

    protected void btnCancel_Click(object sender, EventArgs e) {
        SetEditMode(false);
        creditCardInput.Clear();
    }
}
