//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Text;

using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Payment;

public partial class PaypalIPNHandler : System.Web.UI.Page {
    private PaypalStandardPaymentProvider paypalStandardProvider;
    private PaypalStandardPaymentProvider PaypalStandardProvider {
        get {
            if (null == paypalStandardProvider)
                paypalStandardProvider = PaypalStandardPaymentProvider.GetProvider();
            return paypalStandardProvider;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        byte[] param = Request.BinaryRead(Request.ContentLength);
        string strRequest = Encoding.ASCII.GetString(param);

        Dictionary<string, string> values;
        if (PaypalStandardProvider.VerifyIPN(strRequest, out values)) {
            decimal total = decimal.Parse(values["mc_gross"]);
            string orderNumber = values["custom"];
            Order order = Order.Get(orderNumber);
            PaymentTransaction trans = new PaymentTransaction();
            trans.PaymentGatewayType = PaymentGatewayType.Paypal_Standard;
            trans.PaymentTransactionType = PaymentTransactionType.Sale;
            trans.Amount = total;
            trans.TransactionDate = DateTime.Parse(values["payment_date"]);
            trans.AuthorizationCode = string.Format("{0}, {1}", values["payment_type"], values["payer_id"]);
            trans.AVS = values["payer_status"];
            trans.CVV = values["payment_status"];
            trans.Debug = strRequest;
            trans.Success = true;
            trans.Add(order.OrderNumber);

            if (Constant.DB.OrderStatusPaypalStandardAwaitingPayment == order.OrderStatus.StatusId)
                order.SetToNextStatusInPipeline(string.Format("Received payment notification from PayPal. Total Charge: {0}.", total));
            else if (values["payment_status"].Equals("Completed")) {
                order.SetToNextStatusInPipeline(string.Format("Received payment status ({0}) from PayPal", values["payment_status"]));
            } else {
                Order.SetStatus(order.OrderId, Constant.DB.OrderStatusUnderReview, string.Format("Received payment status ({0}) from PayPal",values["payment_status"]));
            }
        } else {
            ApplicationException ex = new ApplicationException("PayPal IPN Invalid");
            ex.Data.Add("response", strRequest);
            throw ex;
        }
    }
}
