//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_ProductList : System.Web.UI.UserControl {
    private ProductListType type = ProductListType.Featured;
    public ProductListType Type {
        get { return type; }
        set { type = value; }
    }

    private string manufacturer = null;
    public string Manufacturer {
        get { return manufacturer; }
        set { manufacturer = value; }
    }

    private decimal? priceFrom = null;
    public decimal? PriceFrom {
        get { return priceFrom; }
        set { priceFrom = value; }
    }

    private decimal? priceTo = null;
    public decimal? PriceTo {
        get { return priceTo; }
        set { priceTo = value; }
    }

    private int pageNumber = 1;
    public int PageNumber {
        get { return pageNumber; }
        set { pageNumber = value; }
    }

    private ProductSortBy sortby = ProductSortBy.FeaturedItem;
    public ProductSortBy Sortby {
        get { return sortby; }
        set { sortby = value; }
    }

    private int totalNumber;
    public int TotalNumber {
        get { return totalNumber; }
        set { totalNumber = value; }
    }

    public int ProductItemsPerPage { get; set; }
    public int ColumnCount {
        get { return dlProducts.RepeatColumns; }
        set { dlProducts.RepeatColumns = value; }
    }

    private bool enableCache = false;
    public bool EnableCache {
        get { return enableCache; }
        set { enableCache = value; }
    }

    public bool EditorDisabled { get ; set; }

    public int ProductCount {
        get { return dlProducts.Items.Count; }
    }

    protected void Page_Load(object sender, EventArgs e) {
        EnableViewState = WebUtils.IsPageEditorEnable();

        List<Product> products;
        if (enableCache) {
            string cacheKey = string.Format("{0}_ProductList_{1}_{2}_{3}_{4}_{5}_{6}_{7}_{8}", SiteNavigation.GetHost(), type, ProductItemsPerPage, pageNumber, sortby, manufacturer, priceFrom, priceTo,
                StoreConfigurationSection.GetSection().ShowStock);
            object o = Cache[cacheKey];
            if (null == o) {
                products = LoadProducts();
                Cache.Insert(cacheKey, products, null, DateTime.Now.AddHours(Constant.UI.StaticCacheTimeout), System.Web.Caching.Cache.NoSlidingExpiration);
            } else
                products = (List<Product>)o;
        } else {
            products = LoadProducts();
        }
        dlProducts.DataSource = products;
        dlProducts.DataBind();
    }

    private List<Product> LoadProducts() {
        return Product.GetProducts(type, ProductItemsPerPage, (pageNumber - 1) * ProductItemsPerPage, sortby, manufacturer, priceFrom, priceTo,
                StoreConfigurationSection.GetSection().ShowStock, out totalNumber);
    }
}
