//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Core;

internal class Number {
    private int value;
    public int Value {
        get { return value; }
    }

    public Number(int value) {
        this.value = value;
    }

    public static List<Number> Create(int lowerBound, int higherBound) {
        List<Number> numbers = new List<Number>();
        for (int i = lowerBound; i <= higherBound; i++)
            numbers.Add(new Number(i));

        return numbers;
    }
}

public partial class Controls_ProductListResultBar : System.Web.UI.UserControl {
    private int pageNumber, totalNumber;

    public int PageNumber {
        get { return pageNumber; }
        set { pageNumber = value; }
    }

    public int TotalNumber {
        get { return totalNumber; }
        set { totalNumber = value; }
    }

    public int ProductsPerPage { get; set; }

    protected void Page_PreRender(object sender, EventArgs e) {
        if (0 == totalNumber) {
            slcSortBy.Visible = false;
            return;
        }

        //set selected
        string sortby = Utils.GetParameter("sortby", "0");
        foreach (ListItem item in  slcSortBy.Items) {
            if (item.Value == sortby)
                item.Selected = true;
        }

        UIConfigurationSection uiSection = UIConfigurationSection.GetSection();

        litShowResults.Text = string.Format("Showing {0} - {1} of {2} Results", 
            1 + (pageNumber - 1) * ProductsPerPage,
            Math.Min(totalNumber, pageNumber * ProductsPerPage), 
            totalNumber);

        int totalPages = totalNumber / ProductsPerPage + (0 == totalNumber % ProductsPerPage ? 0 : 1);
        int prevPageNumber = pageNumber - Constant.UI.PageJumpCount;
        int nextJumpCount = Constant.UI.PageJumpCount;
        if (prevPageNumber < 1) {
            //since we reach to the beginning increase nextjumpcount so that we show same number of jump pages
            nextJumpCount += 1 - prevPageNumber;
            prevPageNumber = 1;
        }
        int nextPageNumber = pageNumber + nextJumpCount;
        if (nextPageNumber > totalPages) {
            //since we reach to the end check if we could increase prevjumpcount so that we show same number of jump pages
            if (prevPageNumber > 1) {
                prevPageNumber = Math.Max(1, prevPageNumber - (nextPageNumber - totalPages));
            }
            nextPageNumber = totalPages;
        }

        lblPrev.Visible = 1 != prevPageNumber;
        lblNext.Visible = nextPageNumber != totalPages;

        if (1 == pageNumber)
            lnkPrev.Visible = false;
        else {
            lnkPrev.Visible = true;
            lnkPrev.NavigateUrl = SiteNavigation.UpdateUrl(Request.RawUrl, GetReplacementQueryString(pageNumber - 1));
        }

        if (totalPages == pageNumber)
            lnkNext.Visible = false;
        else {
            lnkNext.Visible = true;
            lnkNext.NavigateUrl = SiteNavigation.UpdateUrl(Request.RawUrl, GetReplacementQueryString(pageNumber + 1));
        }

        rptPreviousPages.DataSource = Number.Create(prevPageNumber, pageNumber - 1);
        rptPreviousPages.DataBind();

        rptNextPages.DataSource = Number.Create(pageNumber + 1, nextPageNumber);
        rptNextPages.DataBind();
    }

    protected Dictionary<string, string> GetReplacementQueryString(int pageNumber) {
        Dictionary<string, string> queryString = new Dictionary<string, string>(StringComparer.OrdinalIgnoreCase);
        queryString.Add("page", pageNumber.ToString());
        return queryString;
    }
}
