//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using DotShoppingCart.OpenSource.Core;

public partial class Controls_ProductSummary : BlockUserControl {
    private Product product;
    public Product Product {
        get { return product; }
        set { product = value; }
    }

    private ValidationSummary vdsEdit {
        get { return (ValidationSummary)editor.Edit.FindControl("vdsEdit"); }
    }
    private TextBox txtProductSummaryTemplate {
        get { return (TextBox)editor.Edit.FindControl("txtProductSummaryTemplate"); }
    }
    private Controls_NumberTextBox ntbGridWidth {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbGridWidth"); }
    }
    private Controls_NumberTextBox ntbGridHeight {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbGridHeight"); }
    }
    private Controls_NumberTextBox ntbImageWidth {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbImageWidth"); }
    }
    private Controls_NumberTextBox ntbImageHeight {
        get { return (Controls_NumberTextBox)editor.Edit.FindControl("ntbImageHeight"); }
    }

    private ProductSummaryData productSummaryData = null;

    protected void Page_Load(object sender, EventArgs e) {
        EnableViewState = WebUtils.IsPageEditorEnable();
        ConfigureBlock();

        string[] parts = productSummaryData.Template.Split(new string[] { Constant.UI.ControlToken }, StringSplitOptions.RemoveEmptyEntries);
        foreach (string part in parts) {
            Control c;
            switch (part) {
                case "ProductImage":
                    c = LoadAndBindControl("~/Store/ProductSummary/ProductImage.ascx");
                    break;
                case "ProductName":
                    c = LoadAndBindControl("~/Store/ProductSummary/ProductName.ascx");
                    break;
                case "Price":
                    c = LoadAndBindControl("~/Store/ProductSummary/Price.ascx");
                    break;
                case "ShipEstimate":
                    c = LoadAndBindControl("~/Store/ProductSummary/ShipEstimate.ascx");
                    break;
                case "NewStatus":
                    c = LoadAndBindControl("~/Store/ProductSummary/NewStatus.ascx");
                    break;
                case "ShortDescription":
                    c = LoadAndBindControl("~/Store/ProductSummary/ShortDescription.ascx");
                    break;
                case "AddToCartButton":
                    c = LoadAndBindControl("~/Store/ProductSummary/AddToCartButton.ascx");
                    break;
                default:
                    Literal l = new Literal();
                    l.Text = part;
                    c = l;
                    break;
            }
            placeHolder.Controls.Add(c);
        }
    }

    private Control LoadAndBindControl(string virtualPath) {
        ProductSummaryUserControl c = (ProductSummaryUserControl)LoadControl(virtualPath);
        if (null != product) {
            c.Product = product;
            c.ProductSummaryData = productSummaryData;
            c.DataBind();
        }
        return c;
    }

    private void ConfigureBlock() {
        Block block = Block.GetByName(Constant.UI.ProductSummaryBlockName, ProductSummaryData.DefaultBlock);
        Data = block.Data;
        this.BlockId = block.BlockId;

        editor.BlockUserControl = this;
        editor.BlockUserControl.SetConditionEnabled = editor.BlockUserControl.MoveForwardEnabled =
            editor.BlockUserControl.MoveBackEnabled = editor.BlockUserControl.DeleteEnabled = false;

        productSummaryData = Utils.FromXml<ProductSummaryData>(Data.ToString());

        if (ShowEditor) {
            // Just show one ProductSummaryTemplate Editor
            if ((null == Context.Items["ProductSummaryTemplateEditor"]) ||
                (!(bool)Context.Items["ProductSummaryTemplateEditor"])) {
                pnlBlockContent.CssClass = "BlockEditPanel";
                txtProductSummaryTemplate.Text = productSummaryData.Template;
                ntbGridWidth.Value = productSummaryData.GridWidth;
                ntbGridHeight.Value = productSummaryData.GridHeight;
                ntbImageWidth.Value = productSummaryData.ImageWidth;
                ntbImageHeight.Value = productSummaryData.ImageHeight;
                vdsEdit.ValidationGroup = editor.ValidationGroup = ntbGridWidth.ValidationGroup
                    = ntbGridHeight.ValidationGroup = ntbImageWidth.ValidationGroup = ntbImageHeight.ValidationGroup = this.ClientID;
                Context.Items["ProductSummaryTemplateEditor"] = true;
            } else {
                editor.BlockUserControl.EditorDisabled = true;
            }
        }
    }

    protected void editor_Save(object sender, EventArgs e) {
        ProductSummaryData data = new ProductSummaryData();
        data.Template = string.IsNullOrEmpty(txtProductSummaryTemplate.Text) ? ProductSummaryData.Default.Template : txtProductSummaryTemplate.Text;
        data.GridWidth = ntbGridWidth.Value;
        data.GridHeight = ntbGridHeight.Value;
        data.ImageWidth = ntbImageWidth.Value;
        data.ImageHeight = ntbImageHeight.Value;
        SaveData(data.ToXElement());
        WebUtils.CleanUpThemeFiles();
        Block.ClearCache();
        WebUtils.ReloadPage();
    }
}
