﻿//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;

using AjaxControlToolkit;
using DotShoppingCart.OpenSource.Core;
using DotShoppingCart.OpenSource.Payment;

public partial class Store_SelectPaymentOption : ValidatableUserControl {
    public string ActiveValidationGroup {
        get {
            if (mvwPayment.ActiveViewIndex != 0)
                return null;
            switch (tbcPaymentOptions.ActiveTabIndex) {
                case 0: //credit card
                    if (tbpCreditCard.Visible)
                        return "creditcardCheckout";
                    return null;
                default:
                    return null;
            }
        }
    }

    private int savedActiveIndex {
        get { return (int)ViewState["savedActiveIndex"]; }
        set { ViewState["savedActiveIndex"] = value; }
    }

    
    public bool ShowNullPayment {
        get { return mvwPayment.ActiveViewIndex == 1; }
        set {
            if (value) {
                savedActiveIndex = mvwPayment.ActiveViewIndex;
                mvwPayment.SetActiveView(vwNullPayment);
            } else {
                mvwPayment.ActiveViewIndex = savedActiveIndex;
            }
        }
    }

    public CheckoutPaymentTypeEnum CheckoutPaymentType {
        get {
            switch (mvwPayment.ActiveViewIndex) {
                case 1:
                    return CheckoutPaymentTypeEnum.Null;
                case 2:
                    return CheckoutPaymentTypeEnum.PaypalExpress;
                default: //0
                    switch (tbcPaymentOptions.ActiveTabIndex) {
                        case 1:
                            return CheckoutPaymentTypeEnum.PaypalStandard;
                        default: //0 credit card
                            return CheckoutPaymentTypeEnum.CreditCard;
                    }
            }
        }
        set {
            switch (value) {
                case CheckoutPaymentTypeEnum.Null:
                    mvwPayment.SetActiveView(vwNullPayment);
                    break;
                case CheckoutPaymentTypeEnum.PaypalExpress:
                    mvwPayment.SetActiveView(vwPayPalExpress);
                    break;
                default:
                    mvwPayment.SetActiveView(vwPayment);
                    break;
            }
        }
    }

    public CreditCard CreditCard {
        get {
            if (CheckoutPaymentTypeEnum.CreditCard == CheckoutPaymentType)
                return selectCreditCardPaymentMethod.EnteredCreditCard;
            return null;
        }
    }

    public Address BillingAddress {
        get {
            if (CheckoutPaymentTypeEnum.CreditCard == CheckoutPaymentType)
                return selectCreditCardPaymentMethod.BillingAddress;
            return null;
        }
    }

    protected void Page_Load(object sender, EventArgs e) {
        if (!IsPostBack) {
            if (CreditCardPaymentService.GetProvider() is NullCreditCardPaymentProvider)
                HideTabPanel(tbpCreditCard);
            PaypalStandardPaymentProvider paypalStandardProvider = PaypalStandardPaymentProvider.GetProvider();
            if ((null == paypalStandardProvider) || (!paypalStandardProvider.Enabled))
                HideTabPanel(tbpPayPalStandard);
        }
        
        // workaround for the bug http://www.codeplex.com/AtlasControlToolkit/WorkItem/View.aspx?WorkItemId=8255
        if (!string.IsNullOrEmpty(hidActiveTab.Value))
            tbcPaymentOptions.ActiveTabIndex = int.Parse(hidActiveTab.Value);
    }

    private void HideTabPanel(TabPanel tp) {
        tp.Visible = false;
        tp.HeaderText = string.Empty;
    }
}
