//------------------------------------------------------------------------------
// The contents of this file are subject to the DotShoppingCart Public License Version 1.0 ("License"); you may not use this file except in compliance with the License.
// You may obtain a copy of the License at  http://www.dotshoppingcart.com/Page/license.aspx. 
// Software distributed under the License is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. 
// See the License for the specific language governing rights and limitations under the License.
// 
// The Original Code is DotShoppingCart.
// The Initial Developer of the Original Code is XShan Corp.
// All Rights Reserved.
// 
// Contributor(s): _______. 
//------------------------------------------------------------------------------

using System;
using System.Data;
using System.Configuration;
using System.Collections.Generic;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using DotShoppingCart.OpenSource.Shipping;
using DotShoppingCart.OpenSource.Core;

public partial class Controls_SelectShippingMethod : System.Web.UI.UserControl {
    private List<ShippingMethod> methods {
        get { return (List<ShippingMethod>)ViewState["methods"]; }
        set { ViewState["methods"] = value; }
    }

    private string GetRadioButtonId(int index) {
        return string.Format("rdbShipping_{0}", index);
    }

    public override void DataBind() {
        base.DataBind();
        pnlEmpty.Visible = false;
        SiteConfigurationSection section = SiteConfigurationSection.GetSection();
        methods = ShippingService.GetShippingMethods(ShippingPackage.GetShippingPackage(Cart.Get(),
            (Address)Session["ShippingAddress"], section.LocationCountry, section.LocationState, section.LocationZipcode));
        rptShippingMethods.DataSource = methods;
        rptShippingMethods.DataBind();

        //Check if there is a shipping method selected. If not, then clear Session["ShippingMethod"]
        bool selected = false;
        foreach (RepeaterItem item in rptShippingMethods.Items) {
            RadioButton rdoShiping = (RadioButton)item.FindControl("rdoShiping");
            if (rdoShiping.Checked) {
                selected = true;
                break;
            }
        }
        if (!selected)
            Session["ShippingMethod"] = null;

    }

    protected bool IsShippingMethodSelected(ShippingMethod method) {
        ShippingMethod selected = (ShippingMethod)Session["ShippingMethod"];
        if ((null != selected) &&
            (0 == string.Compare(method.Name, selected.Name))) {
            Session["ShippingMethod"] = method; //reset so that the price is right.
            return true;
        }
        return false;
    }

    protected void rdoShiping_CheckedChanged(object sender, EventArgs e) {
        for (int i = 0; i < rptShippingMethods.Items.Count; i++ ) {
            RepeaterItem item = rptShippingMethods.Items[i];
            RadioButton rdoShiping = (RadioButton)item.FindControl("rdoShiping");
            if (sender == rdoShiping) {
                Session["ShippingMethod"] = methods[i];
            } else if ((null != rdoShiping) && (rdoShiping.Checked))
                rdoShiping.Checked = false;
        }
    }
}
